@@ -25,8 +25,6 @@ import sys
 import time
 import warnings
 
-warnings.filterwarnings("ignore")
-
 # ----------------------------------------------------------------------------------------------------------------------
 # third party imports
 # ----------------------------------------------------------------------------------------------------------------------
@@ -35,7 +33,9 @@ import matplotlib.pyplot as plt
 import matplotlib as mpl
 import numpy as np
 import scipy
-from tqdm.autonotebook import tqdm
+from tqdm import tqdm
+
+warnings.filterwarnings("ignore")
 
 # ======================================================================================================================
 # Tells here the methods or object we allow to import from this library
@@ -44,21 +44,22 @@ from tqdm.autonotebook import tqdm
 __all__ = [
     # Useful librairies alias for the end user avoiding to load them
     # --------------------------------------------------------------
-    
+
     'np', 'plt', 'scipy', 'os', 'sys', 'mpl',
-    
-    ### methods and objects from other packages will be added
-    ### later on this module (see below)
+
+    # methods and objects from other packages will be added
+    # later on this module (see below)
 
 ]
 
 # ======================================================================================================================
 # Progress bar
 # ======================================================================================================================
-if os.environ.get('USE_TQDM','Yes') == 'Yes':
+if os.environ.get('USE_TQDM', 'Yes') == 'Yes':
     pbar = tqdm(total=1211)
     pbar.set_description('Loading SpectroChemPy API')
     val_tqdm = [1, 39, 52, 83, 83, 89, 92, 93, 94, 95, 96, 97, 98, 99, 100]
+
     def _pbar_update(i):
         if i == 'CLOSE':
             pbar.clear()
@@ -67,26 +68,26 @@ if os.environ.get('USE_TQDM','Yes') == 'Yes':
             time.sleep(.1)
             pbar.update(val_tqdm[i])
 else:
+
     def _pbar_update(i):
         pass
-    
-    
+
 # ======================================================================================================================
 # loading module libraries
 # here we also construct the __all__ list automatically
 # ======================================================================================================================
 
 _pbar_update(0)
-from spectrochempy.application import SpectroChemPy
+from spectrochempy.application import SpectroChemPy   # noqa: E402
 
 app = SpectroChemPy()
-# __all__ += ['app']
+__all__ += ['app']
 
 # ======================================================================================================================
 # logging functions
 # ======================================================================================================================
 
-from spectrochempy.utils import pstr
+from spectrochempy.utils import pstr   # noqa: E402
 
 
 def print_(*args, **kwargs):
@@ -138,7 +139,7 @@ def warning_(*args, **kwargs):
 
 __all__ += ['info_', 'debug_', 'error_', 'warning_', 'print_']
 
-from spectrochempy.application import (
+from spectrochempy.application import (          # noqa: E402
     __version__ as version,
     __release__ as release,
     __copyright__ as copyright,
@@ -153,7 +154,6 @@ from spectrochempy.application import (
     CRITICAL,
     INFO,
     available_styles,
-    check_for_update,
 )
 
 general_preferences = app.general_preferences
@@ -175,7 +175,7 @@ def get_loglevel():
 
 
 __all__ += [
-    ### Helpers
+    # Helpers
     'DEBUG',
     'WARNING',
     'ERROR',
@@ -188,8 +188,8 @@ __all__ += [
     'available_styles',
     'set_loglevel',
     'get_loglevel',
-    
-    ### Info
+
+    # Info
     'copyright',
     'version',
     'release',
@@ -205,9 +205,8 @@ __all__ += [
 # load the default style
 # print("mpl_config_dir", mpl.get_configdir(), plt.style.available)
 try:
-    # print('styles', project_preferences.style)
     plt.style.use(project_preferences.style)
-except:
+except Exception:
     pass  # if the scp styles are not yet installed, ignore it
 
 # IPython methods
@@ -215,165 +214,120 @@ except:
 # we put them before so that we can eventually overwrite them
 
 _pbar_update(1)
-from IPython.core.display import *
-from IPython.core import display
+#from IPython.core.display import *          # noqa: E402,F403,F401
+#from IPython.core import display            # noqa: E402
 
-__all__.extend(display.__all__)
+#__all__.extend(display.__all__)
 
-from IPython.lib.display import *
-from IPython.lib import display
+#from IPython.lib.display import *           # noqa: E402,F401,F403
+#from IPython.lib import display             # noqa: E402
 
-__all__.extend(display.__all__)
+#__all__.extend(display.__all__)
 
 """
-This packages contains most of the core methods expose in the spectrochempy 
-API.
+This packages contains most of the core methods expose in the spectrochempy API.
 
 """
 # constants
 # ----------------------------------------------------------------------------------------------------------------------
-from spectrochempy.utils import show, MASKED, NOMASK, EPSILON, INPLACE
+from spectrochempy.utils import show, MASKED, NOMASK, EPSILON, INPLACE  # noqa: E402
 
 __all__ += ['show', 'MASKED', 'NOMASK', 'EPSILON', 'INPLACE']
 
-# optional libraries
-# ----------------------------------------------------------------------------------------------------------------------
-
-try:
-    import sympy as sym
-    
-    HAS_SYMPY__ = True
-    __all__.append('sym')
-except ImportError:
-    HAS_SYMPY = True
-
-__all__.append('HAS_SYMPY')
-
-try:
-    import sklearn as skl
-    
-    HAS_SCIKITLEARN = True
-    __all__.append('skl')
-except ImportError:
-    HAS_SCIKITLEARN = False
-
-__all__.append('HAS_SCIKITLEARN')
-
-try:
-    import xarray as xr
-    
-    HAS_XARRAY = True
-    __all__.append('xr')
-except:
-    HAS_XARRAY = False
-
-__all__.append('HAS_XARRAY')
-
-try:
-    import pandas as pd
-    
-    HAS_PANDAS = True
-    __all__.append('pd')
-except:
-    HAS_PANDAS = False
-
-__all__.append('HAS_PANDAS')
 
 # dataset
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(2)
-from spectrochempy.core.dataset.api import *
-from spectrochempy.core.dataset import api
+from spectrochempy.core.dataset.api import *     # noqa: E402,F403,F401
+from spectrochempy.core.dataset import api       # noqa: E402
 
 __all__ += api.__all__
 
 # plotters
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(3)
-from spectrochempy.core.plotters.api import *
-from spectrochempy.core.plotters import api
+from spectrochempy.core.plotters.api import *      # noqa: E402,F403,F401
+from spectrochempy.core.plotters import api        # noqa: E402
 
 __all__ += api.__all__
 
-
 # processors
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(4)
-from spectrochempy.core.processors.api import *
-from spectrochempy.core.processors import api
+from spectrochempy.core.processors.api import *     # noqa: E402,F403,F401
+from spectrochempy.core.processors import api       # noqa: E402
 
 __all__ += api.__all__
 
-
 # readers
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(5)
-from spectrochempy.core.readers.api import *
-from spectrochempy.core.readers import api
+from spectrochempy.core.readers.api import *        # noqa: E402,F403,F401
+from spectrochempy.core.readers import api          # noqa: E402
 
 __all__ += api.__all__
 
 # writers
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(6)
-from spectrochempy.core.writers.api import *
-from spectrochempy.core.writers import api
+from spectrochempy.core.writers.api import *         # noqa: E402,F403,F401
+from spectrochempy.core.writers import api           # noqa: E402
 
 __all__ += api.__all__
 
 # units
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(7)
-from spectrochempy.units.units import *
-from spectrochempy.units import units
+from spectrochempy.units.units import *               # noqa: E402,F403,F401
+from spectrochempy.units import units                 # noqa: E402
 
 __all__ += units.__all__
 
 # databases
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(8)
-from spectrochempy.databases.api import *
-from spectrochempy.databases import api
+from spectrochempy.databases.api import *              # noqa: E402,F403,F401
+from spectrochempy.databases import api                # noqa: E402
 
 __all__ += api.__all__
 
 # analysis
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(9)
-from spectrochempy.core.analysis.api import *
-from spectrochempy.core.analysis import api
+from spectrochempy.core.analysis.api import *           # noqa: E402,F403,F401
+from spectrochempy.core.analysis import api             # noqa: E402
 
 __all__ += api.__all__
 
 # fitting
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(10)
-from spectrochempy.core.fitting.api import *
-from spectrochempy.core.fitting import api
+from spectrochempy.core.fitting.api import *             # noqa: E402,F403,F401
+from spectrochempy.core.fitting import api               # noqa: E402
 
 __all__ += api.__all__
 
 # project
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(11)
-from spectrochempy.core.project.api import *
-from spectrochempy.core.project import api
+from spectrochempy.core.project.api import *              # noqa: E402,F403,F401
+from spectrochempy.core.project import api                # noqa: E402
 
 __all__ += api.__all__
 
 # script
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(12)
-from spectrochempy.core.scripts.api import *
-from spectrochempy.core.scripts import api
+from spectrochempy.core.scripts.api import *              # noqa: E402,F403,F401
+from spectrochempy.core.scripts import api                # noqa: E402
 
 __all__ += api.__all__
 
 # widgets
 # ----------------------------------------------------------------------------------------------------------------------
 _pbar_update(13)
-from spectrochempy.widgets.api import *
-from spectrochempy.widgets import api
+from spectrochempy.widgets.api import *                    # noqa: E402,F403,F401
+from spectrochempy.widgets import api                      # noqa: E402
 
 __all__ += api.__all__
 
@@ -401,7 +355,6 @@ _pbar_update(14)
 
 _pbar_update('CLOSE')
 
-
 _started = app.start()
 
 warnings.filterwarnings(action='ignore', module='matplotlib', category=UserWarning)
