@@ -9,12 +9,13 @@
 
 __all__ = ['trapz']
 
-__dataset_methods__  = __all__
+__dataset_methods__ = ['trapz']
 
 import scipy.signal
 
 """wrapper of scipy.signal integration function"""
 
+
 def trapz(dataset, dim='x'):
     '''
      Wrapper of scpy.signal.find_peaks(). Integrate along the given dim using the composite trapezoidal rule.
@@ -43,5 +44,3 @@ def trapz(dataset, dim='x'):
     if dataset.coord([dim]).reversed:
         res *= -1
     return res
-
-
