@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 #
 # ======================================================================================================================
@@ -14,14 +13,14 @@ This module implements the IRIS class.
 __all__ = ['IRIS']
 __dataset_methods__ = []
 
-from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.ndcoord import Coord
-from spectrochempy.core.dataset.npy import dot
-
 import numpy as np
+import quadprog
 from matplotlib import pyplot as plt
 from scipy import optimize
-import quadprog
+
+from spectrochempy.core.dataset.ndcoord import Coord
+from spectrochempy.core.dataset.nddataset import NDDataset
+
 
 class IRIS:
     """
@@ -37,9 +36,9 @@ class IRIS:
         param : dict
             Dict of inversion parameters with the following keys :
 
-            *   'custom_kernel': a two-variable lambda function ker(p, eps) where p and eps are the external experimental
-                variable and  the internal physico-chemical parameter, respectively. If not given, one of the
-                pre-defined kernel must be defined in param['kernel'], below.
+            *   'custom_kernel': a two-variable lambda function ker(p, eps) where p and eps are the external
+                experimental variable and  the internal physico-chemical parameter, respectively. If not given,
+                one of the pre-defined kernel must be defined in param['kernel'], below.
             *   'kernel': the name of  the kernel used to make the inversion. The kernel K(p, eps) is a functional
                 relationship holding between 'p', the experimental variable that was changed in the rows direction of X
                 (e.g. temperature, pressure, time, ...) and the concentration of pure species characterized
@@ -66,18 +65,22 @@ class IRIS:
 
         elif 'kernel' in param:
             if param['kernel'].lower() == 'langmuir':
-                ker = lambda p_, eps_: np.exp(-eps_) * p_ / (1 + np.exp(-eps_) * p_)
+                def ker(p_, eps_):
+                    return np.exp(-eps_) * p_ / (1 + np.exp(-eps_) * p_)
 
             elif param['kernel'].lower() == 'ca':
-                ker = lambda p_, eps_: 0 if p_ < np.exp(eps_) else 1
+                def ker(p_, eps_):
+                    return 0 if p_ < np.exp(eps_) else 1
 
             elif param['kernel'].lower() == 'reactant-first-order':
-                ker = lambda t, lnk: np.exp(-1 * np.exp(lnk) * t)
+                def ker(t, lnk):
+                    return np.exp(-1 * np.exp(lnk) * t)
 
             elif param['kernel'].lower() == 'product-first-order':
-                ker = lambda t, lnk: 1 - np.exp(-1 * np.exp(lnk) * t)
+                def ker(t, lnk):
+                    return 1 - np.exp(-1 * np.exp(lnk) * t)
             else:
-                raise NameError('This kernel: <{}> is not implemented'.format(ker))
+                raise NameError(f"This kernel: <{param['kernel']}> is not implemented")
 
         else:
             raise NameError('A kernel must be given !')
@@ -91,13 +94,13 @@ class IRIS:
         if 'lambdaRange' not in param:
             lambdaRange = None
         else:
-            lambdaRange=param['lambdaRange']
-        if lambdaRange == None:
+            lambdaRange = param['lambdaRange']
+        if lambdaRange is None:
             regularization = False
             searchLambda = False
             lamb = [0]
         elif len(lambdaRange) == 2:
-            regularization =True
+            regularization = True
             searchLambda = True
         elif len(param['lambdaRange']) == 3:
             regularization = True
@@ -125,10 +128,10 @@ class IRIS:
             p = X.y
             pval = X.y.data  # values
 
-        if 'guess' in param:
-            guess = param['guess']
-        else:
-            guess = 'previous'
+        # if 'guess' in param:
+        #     guess = param['guess']       <-- # TODO: never used.
+        # else:
+        #     guess = 'previous'
 
         verbose = kwargs.get('verbose', False)
 
@@ -172,7 +175,7 @@ class IRIS:
                       .format(X.shape[1], X.shape[0]))
             # une scipy.nnls() to solve the linear problem: X = K f
             for j, freq in enumerate(X.x.data):
-                f[0, :, j] = optimize.nnls(K.data, X[:,j].data.squeeze())[0]
+                f[0, :, j] = optimize.nnls(K.data, X[:, j].data.squeeze())[0]
             res = X.data - np.dot(K.data, f[0].data)
             RSS[0] = np.sum(res ** 2)
             SM[0] = np.linalg.norm(np.dot(np.dot(np.transpose(f[0]), S), f[0]))
@@ -191,20 +194,25 @@ class IRIS:
             b = np.zeros(len(eps))
 
             def solve_lambda(X, K, G0, lamda, S, verbose):
-                ''' QP optimization
+                """
+                QP optimization
+
                 parameters:
-                ----------
+                -----------
                 X: NDDataset of experimental spectra
                 K: NDDataset, kernel datase
-                G0: the lamda independent part of G 
+                G0: the lambda independent part of G
                 lamda: regularization parameter
                 S: penalty function (shaprness)
                 verbose: print info
-    
-                returns: f, RSS and SM for a given regularization parameter
-                ------- '''
+
+                returns:
+                --------
+                f, RSS and SM for a given regularization parameter
+
+                """
                 fi = np.zeros((len(eps), len(X.x.data)))
-                if verbose :
+                if verbose:
                     print('... Solving for lambda = {} ...'.format(lamda))
                 G = nearestPD(G0 + 2 * lamda * S)
                 for j, freq in enumerate(X.x.data):
@@ -218,46 +226,49 @@ class IRIS:
                 return fi, RSSi, SMi
 
             def menger(x, y):
-                '''returns the Menger curvature of a triplet of
-                points. x, y = sets of 3 cartesian coordinates '''
+                """
+                returns the Menger curvature of a triplet of
+                points. x, y = sets of 3 cartesian coordinates
 
-                numerator = 2 * (x[0]*y[1] + x[1]*y[2] + x[2]*y[0]
-                                 - x[0]*y[2] - x[1]*y[0] - x[2]*y[1])
+                """
+
+                numerator = 2 * (x[0] * y[1] + x[1] * y[2] + x[2] * y[0]
+                                 - x[0] * y[2] - x[1] * y[0] - x[2] * y[1])
                 # euclidian distances
-                r01 = (x[1] - x[0])**2 + (y[1] - y[0])**2
-                r12 = (x[2] - x[1])**2 + (y[2] - y[1])**2
-                r02 = (x[2] - x[0])**2 + (y[2] - y[0])**2
+                r01 = (x[1] - x[0]) ** 2 + (y[1] - y[0]) ** 2
+                r12 = (x[2] - x[1]) ** 2 + (y[2] - y[1]) ** 2
+                r02 = (x[2] - x[0]) ** 2 + (y[2] - y[0]) ** 2
 
                 denominator = np.sqrt(r01 * r12 * r02)
-                return numerator/denominator
+                return numerator / denominator
 
-            if not searchLambda :
+            if not searchLambda:
                 if verbose:
                     print('Solving for {} wavenumbers, {} spectra and {} regularization parameters \n'
-                        .format(X.shape[1], X.shape[0], len(lamb)))
+                          .format(X.shape[1], X.shape[0], len(lamb)))
 
                     for i, lamda in enumerate(lamb):
-                        f[i], RSS [i], SM[i] = solve_lambda(X, K, G0, lamda, S, verbose)
+                        f[i], RSS[i], SM[i] = solve_lambda(X, K, G0, lamda, S, verbose)
 
             else:
                 if verbose:
                     print('Solving for {} wavenumbers and {} spectra, search regularization parameter '
-                      'in [10**{}, 10**{}]\n'
+                          'in [10**{}, 10**{}]\n'
                           .format(X.shape[1], X.shape[0], str(min(lambdaRange)), str(max(lambdaRange))))
 
-                    x = lamda = np.ndarray((4))
+                    x = np.ndarray((4))
                     epsilon = 0.1
                     phi = (1 + np.sqrt(5)) / 2
 
                     x[0] = min(lambdaRange)
                     x[3] = max(lambdaRange)
-                    x[1] = (x[3] + phi * x[0])/ (1 + phi)
+                    x[1] = (x[3] + phi * x[0]) / (1 + phi)
                     x[2] = x[0] + x[3] - x[1]
-                    lamb = 10**x
+                    lamb = 10 ** x
                     if verbose:
                         print('Log lambda= ' + str(x))
                     for i, xi in enumerate(x):
-                        f[i], RSS[i], SM[i] = solve_lambda(X, K, G0, 10**xi, S, verbose)
+                        f[i], RSS[i], SM[i] = solve_lambda(X, K, G0, 10 ** xi, S, verbose)
 
                     Rx = RSS
                     Sy = SM
@@ -267,44 +278,53 @@ class IRIS:
                         if verbose:
                             print('Curvatures: C1 = {} ; C2 = {}'.format(C1, C2))
                         while C2 < 0:
-                            x[3] = x[2]; Rx[3] = Rx[2]; Sy[3] = Sy[2]
-                            x[2] = x[1]; Rx[2] = Rx[1]; Sy[2] = Sy[1]
+                            x[3] = x[2]
+                            Rx[3] = Rx[2]
+                            Sy[3] = Sy[2]
+                            x[2] = x[1]
+                            Rx[2] = Rx[1]
+                            Sy[2] = Sy[1]
                             x[1] = (x[3] + phi * x[0]) / (1 + phi)
                             if verbose:
                                 print('Log lambda= ' + str(x))
-                            f_, Rx[1], S[1] = solve_lambda(X, K, G0, 10**x[1], S, verbose)
-                            lamb = np.append(lamb, np.array(10**x[1]))
+                            f_, Rx[1], S[1] = solve_lambda(X, K, G0, 10 ** x[1], S, verbose)
+                            lamb = np.append(lamb, np.array(10 ** x[1]))
                             f = np.concatenate((f, np.atleast_3d(f_.T).T))
                             RSS = np.concatenate((RSS, np.array(Rx[1:2])))
                             SM = np.concatenate((SM, np.array(Sy[1:2])))
                             C2 = menger(Rx[1:4], Sy[1:4])
                             print('new curvature: C2 = {}'.format(C2))
                         if C1 > C2:
-                            xx = x[1]
-                            x[3] = x[2]; Rx[3] = Rx[2]; Sy[3] = Sy[2]
-                            x[2] = x[1]; Rx[2] = Rx[1]; Sy[2] = Sy[1]
+                            x[3] = x[2]
+                            Rx[3] = Rx[2]
+                            Sy[3] = Sy[2]
+                            x[2] = x[1]
+                            Rx[2] = Rx[1]
+                            Sy[2] = Sy[1]
                             x[1] = (x[3] + phi * x[0]) / (1 + phi)
                             if verbose:
                                 print('Log lambda= ' + str(x))
-                            f_, Rx[1], S[1] = solve_lambda(X, K, G0, 10**x[1], S, verbose)
+                            f_, Rx[1], S[1] = solve_lambda(X, K, G0, 10 ** x[1], S, verbose)
                             f = np.concatenate((f, np.atleast_3d(f_.T).T))
-                            lamb = np.append(lamb, np.array(10**x[1]))
+                            lamb = np.append(lamb, np.array(10 ** x[1]))
                             RSS = np.concatenate((RSS, np.array(Rx[1:2])))
                             SM = np.concatenate((SM, np.array(Sy[1:2])))
                         else:
-                            xx = x[2]
-
-                            x[0] = x[1]; Rx[0] = Rx[1]; Sy[0] = Sy[1]
-                            x[1] = x[2]; Rx[1] = Rx[2]; Sy[1] = Sy[2]
+                            x[0] = x[1]
+                            Rx[0] = Rx[1]
+                            Sy[0] = Sy[1]
+                            x[1] = x[2]
+                            Rx[1] = Rx[2]
+                            Sy[1] = Sy[2]
                             x[2] = x[0] - (x[1] - x[3])
                             if verbose:
                                 print('Log lambda= ' + str(x))
-                            f_, Rx[2], S[2] = solve_lambda(X, K, G0, 10**x[2], S, verbose)
+                            f_, Rx[2], S[2] = solve_lambda(X, K, G0, 10 ** x[2], S, verbose)
                             f = np.concatenate((f, np.atleast_3d(f_.T).T))
-                            lamb = np.append(lamb, np.array(10**x[2]))
+                            lamb = np.append(lamb, np.array(10 ** x[2]))
                             RSS = np.concatenate((RSS, np.array(Rx[1:2])))
                             SM = np.concatenate((SM, np.array(Sy[1:2])))
-                        if (10**x[3] - 10**x[0])/10**x[3] < epsilon:
+                        if (10 ** x[3] - 10 ** x[0]) / 10 ** x[3] < epsilon:
                             break
                     if verbose:
                         print('\n optimum found !')
@@ -325,12 +345,11 @@ class IRIS:
         self.RSS = RSS
         self.SM = SM
 
-
     def reconstruct(self):
         """
         Transform data back to the original space
 
-        The following matrix operation is performed : :math:`\hat{X} = K.f[i]`
+        The following matrix operation is performed : :math:`\\hat{X} = K.f[i]`
         for each value of the regularization parameter.
 
         Returns
@@ -362,6 +381,7 @@ class IRIS:
         Returns
         -------
         ax : subplot axis
+
         """
 
         fig = plt.figure()
@@ -383,12 +403,14 @@ class IRIS:
 
         Parameters
         ----------
-        index : optional, int, list or tuple of int. Index(es) of the inversions (i.e. of the lambda values) to consider.
-         If 'None': plots for all indices. default: None
+        index : optional, int, list or tuple of int.
+            Index(es) of the inversions (i.e. of the lambda values) to consider.
+            If 'None': plots for all indices. default: None
 
         Returns
         -------
         list of axes
+
         """
 
         colX, colXhat, colRes = kwargs.get('colors', ['blue', 'green', 'red'])
@@ -404,7 +426,7 @@ class IRIS:
             ax = self.X.plot()
             ax.plot(self.X.x.data, X_hats[i].squeeze().T.data, color=colXhat)
             ax.plot(self.X.x.data, res.T.data, color=colRes)
-            ax.set_title('2D IRIS merit plot, $\lambda$ = ' + str(self.lamda[i]))
+            ax.set_title(r'2D IRIS merit plot, $\lambda$ = ' + str(self.lamda[i]))
             axeslist.append(ax)
         return axeslist
 
@@ -414,12 +436,16 @@ class IRIS:
 
         Parameters
         ----------
-        index : optional, int, list or tuple of int. Index(es) of the inversions (i.e. of the lambda values) to consider.
-         If 'None': plots for all indices. default: None
-        other optional arguments are passed in the plots
+        index : optional, int, list or tuple of int.
+            Index(es) of the inversions (i.e. of the lambda values) to consider.
+            If 'None': plots for all indices. default: None
+        kwargs:
+            other optional arguments are passed in the plots
+
         Returns
         -------
         list of axes
+
         """
 
         axeslist = []
@@ -431,6 +457,7 @@ class IRIS:
             self.f[i].plot(method='map', **kwargs)
         return axeslist
 
+
 # --------------------------------------------
 # Utility functions
 
@@ -500,15 +527,16 @@ def nearestPD(A):
     # `spacing` will, for Gaussian random matrixes of small dimension, be on
     # othe order of 1e-16. In practice, both ways converge, as the unit test
     # below suggests.
-    I = np.eye(A.shape[0])
+    Ie = np.eye(A.shape[0])
     k = 1
     while not isPD(A3):
         mineig = np.min(np.real(np.linalg.eigvals(A3)))
-        A3 += I * (-mineig * k**2 + spacing)
+        A3 += Ie * (-mineig * k ** 2 + spacing)
         k += 1
         print('makes PD matrix')
     return A3
 
+
 def isPD(B):
     """Returns true when input is positive-definite, via Cholesky
 
@@ -518,6 +546,3 @@ def isPD(B):
         return True
     except np.linalg.LinAlgError:
         return False
-
-
-
