@@ -17,14 +17,14 @@ __dataset_methods__ = []
 
 import numpy as np
 from traitlets import HasTraits, Instance
-from collections.abc import Iterable
-
+# from collections.abc import Iterable
 
 from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.core.analysis.pca import PCA
 from spectrochempy.core.dataset.npy import dot
 from spectrochempy.core import info_, set_loglevel, INFO
 
+
 class MCRALS(HasTraits):
     """
     Performs MCR-ALS of a dataset knowing the initial C or St matrix
@@ -50,7 +50,7 @@ class MCRALS(HasTraits):
             Initial concentration or spectra
         param : dict
             Dict of optimization parameters with the following keys :
-        
+
             * tol : float, optional,  default=0.1
                 convergence criterion on the change of resisuals.
                 (percent change of standard deviation of residuals).
@@ -69,16 +69,16 @@ class MCRALS(HasTraits):
                 index of species for which a concentration profile is provided by an external function.
             *  getExtlConc : callable
                 an external function that will provide `n_ext` concentration profiles:
-                    getExtConc(C, extConc, ext_to_C_idx, \*args) -> extC
-                
+                    getExtConc(C, extConc, ext_to_C_idx, *args) -> extC
+
                 or
-                    getExtConc(C, extConc, ext_to_C_idx, \*args) -> (extC, out2, out3, ...)
-                
-                where C is the current concentration matrix, \*args are the parameters needed to completely
+                    getExtConc(C, extConc, ext_to_C_idx, *args) -> (extC, out2, out3, ...)
+
+                where C is the current concentration matrix, *args are the parameters needed to completely
                 specify the function, extC is a  nadarray or NDDataset of shape (C.y, n_ext), and out1, out2, ... are
                 supplementary outputs returned by the function (e.g. optimized rate parameters)
             * args : tuple, optional.
-                Extra arguments passed to tthe external function
+                Extra arguments passed to the external function
             * external_to_C_idx : array or tuple, Default=np.arange(next)
                 indicates the correspondence between the indexes of external chemical
                 profiles and the columns of the C matrix. [1, None, 0] indicates that the first external profile is the
@@ -90,23 +90,24 @@ class MCRALS(HasTraits):
         verbose : bool
             If set to True, prints a summary of residuals and residuals change at each iteration. default = False.
             In any case, the same information is returned in self._log
-        
+
         Attributes
         ----------
-        self._X :
+        self.X :
             the original dataset
-        self._param :
+        self.param :
             the parameters used to perform the MCR als
-        self._extC :
+        self.extC :
             the last concentration profiles including external profiles
-        self._extOutput :
+        self.extOutput :
             the last output of the external function used to get
-        self._C :
+        self.C :
             the final concentration profiles
-        self._St :
+        self.St :
             the final spectral profiles
-        self._log :
+        self.log :
             logs
+
         """
 
         verbose = kwargs.get('verbose', False)
@@ -120,7 +121,7 @@ class MCRALS(HasTraits):
 
         if type(guess) is np.ndarray:
             guess = NDDataset(guess)
-            
+
         if X.shape[0] == guess.shape[0]:
             initConc = True
             C = guess.copy()
@@ -140,7 +141,7 @@ class MCRALS(HasTraits):
         ny, nx = X.shape
 
         # makes a PCA with same number of species
-        Xpca = PCA(X).reconstruct(n_pc = nspecies)
+        Xpca = PCA(X).reconstruct(n_pc=nspecies)
 
         # Get optional parameters in kwargs or set them to their default
         # ------------------------------------------------------------------------
@@ -148,7 +149,7 @@ class MCRALS(HasTraits):
         # TODO: make a preference  file to set this kwargs
         param = kwargs.get('param', dict())
 
-        ### optimization
+        # optimization
 
         tol = param.get('tol', 0.1)
         maxit = param.get('maxit', 50)
@@ -173,7 +174,7 @@ class MCRALS(HasTraits):
         if externalConc is not None:
             try:
                 getExternalConc = param.get('getExternalConc')
-            except:
+            except Exception:
                 raise ValueError('A function must be given to get the external concentration profile(s)')
             external_to_C_idx = param.get('external_to_C_idx', externalConc)
             args = param.get('args', ())
@@ -285,13 +286,13 @@ class MCRALS(HasTraits):
                     Q = np.linalg.lstsq(C.data[:, closureConc], closureTarget.T, rcond=None)[0]
                     C.data[:, closureConc] = np.dot(C.data[:, closureConc], np.diag(Q))
                 elif closureMethod == 'constantSum':
-                    totalConc = np.sum(C.data[:,closureConc], axis=1)
-                    C.data[:, closureConc] = C.data[:, closureConc] * closureTarget[:,None] / totalConc[:,None]
+                    totalConc = np.sum(C.data[:, closureConc], axis=1)
+                    C.data[:, closureConc] = C.data[:, closureConc] * closureTarget[:, None] / totalConc[:, None]
 
             # external concentration profiles
             # ------------------------------------------
             if externalConc is not None:
-                extOutput  = getExternalConc(*((C, externalConc, external_to_C_idx,) + args))
+                extOutput = getExternalConc(*((C, externalConc, external_to_C_idx,) + args))
                 if isinstance(extOutput, dict):
                     extC = extOutput['concentrations']
                     args = extOutput['new_args']
@@ -349,8 +350,8 @@ class MCRALS(HasTraits):
                 info_(logentry)
 
             if ndiv == maxdiv:
-                logline = 'Optimization not improved since {} iterations... unconverged or \'tol\' set too small ?\n'.format(
-                    maxdiv)
+                logline = f"Optimization not improved since {maxdiv} iterations... unconverged " \
+                          f"or 'tol' set too small ?\n"
                 logline += 'Stop ALS optimization'
                 logs += logline + '\n'
                 info_(logline)
@@ -366,7 +367,8 @@ class MCRALS(HasTraits):
         self.Chard = Chard
         self.C = C
         if externalConc is not None:
-            self._extOutput = extOutput
+            self.extC = extC
+            self.extOutput = extOutput
         else:
             self.extC = None
             self.extOutput = None
@@ -374,7 +376,6 @@ class MCRALS(HasTraits):
         self.St = St
         self.log = logs
 
-
     def reconstruct(self):
         """
         Transform data back to the original space.
