@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
-#
 # ======================================================================================================================
-# Copyright (©) 2015-2020 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
-# See full LICENSE agreement in the root directory
+#  Copyright (©) 2015-2020 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
 # ======================================================================================================================
 
 """
 This module implement the PCA (Principal Component Analysis) class.
+
 """
 
 __all__ = ['PCA']
@@ -16,24 +14,27 @@ __all__ = ['PCA']
 __dataset_methods__ = []
 
 # ----------------------------------------------------------------------------------------------------------------------
-# imports
+# standard imports
+# ----------------------------------------------------------------------------------------------------------------------
+import warnings
+
+# ----------------------------------------------------------------------------------------------------------------------
+# third-party imports
 # ----------------------------------------------------------------------------------------------------------------------
 import numpy as np
-import warnings
+from matplotlib import pyplot as plt
+from matplotlib.ticker import MaxNLocator, ScalarFormatter
 from scipy.special import gammaln
 from traitlets import HasTraits, Instance
-from matplotlib import pyplot as plt
-from mpl_toolkits.mplot3d import Axes3D
-from matplotlib.ticker import MaxNLocator, ScalarFormatter
 
 # ----------------------------------------------------------------------------------------------------------------------
 # localimports
 # ----------------------------------------------------------------------------------------------------------------------
-from spectrochempy.core.dataset.nddataset import NDDataset, CoordSet
-from spectrochempy.core.dataset.ndcoord import Coord
-from spectrochempy.core.analysis.svd import SVD
-from spectrochempy.core.dataset.npy import diag, dot
 from spectrochempy.core import project_preferences
+from spectrochempy.core.analysis.svd import SVD
+from spectrochempy.core.dataset.ndcoord import Coord
+from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.core.dataset.npy import diag, dot
 from spectrochempy.utils import docstrings, NRed, NBlue
 
 
@@ -89,7 +90,7 @@ class PCA(HasTraits):
             :math:`X' = X - mean(X)`.
         standardized : bool, optional, default:False
             If True the data are scaled to unit standard deviation :
-            :math:`X' = X / \sigma`.
+            :math:`X' = X / \\sigma`.
         scaled : bool, optional, default:False
             If True the data are scaled in the interval [0-1] :
             :math:`X' = (X - min(X)) / (max(X)-min(X))`
@@ -188,7 +189,7 @@ class PCA(HasTraits):
         n_pc = min(n_pc, len(self.ev.data))
         for i in range(n_pc):
             tup = (
-                i + 1, np.sqrt(self.ev.data[i]), self.ev_ratio.data[i], self.ev_cum.data[i])
+                    i + 1, np.sqrt(self.ev.data[i]), self.ev_ratio.data[i], self.ev_cum.data[i])
             s += '#{}  \t{:8.3e}\t\t {:6.3f}\t      {:6.3f}\n'.format(*tup)
 
         return s
@@ -325,8 +326,6 @@ class PCA(HasTraits):
 
         """
 
-        X = self.X
-
         # get n_pc (automatic or determined by the n_pc arguments)
         n_pc = self._get_n_pc(n_pc)
 
@@ -376,8 +375,7 @@ class PCA(HasTraits):
         if self._centered:
             X += self._center
 
-        X.history = 'PCA reconstructed Dataset with {} principal ' \
-                    'components'.format(n_pc)
+        X.history = f'PCA reconstructed Dataset with {n_pc} principal components'
         X.title = self.X.title
         return X
 
@@ -398,7 +396,7 @@ class PCA(HasTraits):
 
     def screeplot(self, n_pc=None, **kwargs):
         """
-        Scree plot of explained variance \+ cumulative variance by PCA.
+        Scree plot of explained variance + cumulative variance by PCA.
 
         Parameters
         ----------
@@ -410,7 +408,7 @@ class PCA(HasTraits):
         n_pc = max(self._get_n_pc(n_pc), 3)
 
         color1, color2 = kwargs.get('colors', [NBlue, NRed])
-        pen = kwargs.get('pen', True)
+        # pen = kwargs.get('pen', True)
         ylim1, ylim2 = kwargs.get('ylims', [(0, 100), 'auto'])
 
         if ylim2 == 'auto':
@@ -465,7 +463,7 @@ class PCA(HasTraits):
         elif color_mapping == 'labels':
 
             labels = list(set(self.S.y.labels))
-            colors = [labels.index(l) for l in self.S.y.labels]
+            colors = [labels.index(lab) for lab in self.S.y.labels]
 
         if len(pcs) == 2:
             # bidimentional score plot
@@ -475,9 +473,9 @@ class PCA(HasTraits):
             ax.set_title('Score plot')
 
             ax.set_xlabel('PC# {} ({:.3f}%)'.format(
-                pcs[0] + 1, self.ev_ratio.data[pcs[0]]))
+                    pcs[0] + 1, self.ev_ratio.data[pcs[0]]))
             ax.set_ylabel('PC# {} ({:.3f}%)'.format(
-                pcs[1] + 1, self.ev_ratio.data[pcs[1]]))
+                    pcs[1] + 1, self.ev_ratio.data[pcs[1]]))
             axsc = ax.scatter(self.S.masked_data[:, pcs[0]],
                               self.S.masked_data[:, pcs[1]],
                               s=30,
@@ -497,18 +495,18 @@ class PCA(HasTraits):
 
         if len(pcs) == 3:
             # tridimensional score plot
-            fig = plt.figure(**kwargs)
+            plt.figure(**kwargs)
             ax = plt.axes(projection='3d')
             ax.set_title('Score plot')
             ax.set_xlabel(
-                'PC# {} ({:.3f}%)'.format(pcs[0] + 1, self.ev_ratio.data[pcs[
-                    0]]))
+                    'PC# {} ({:.3f}%)'.format(pcs[0] + 1, self.ev_ratio.data[pcs[
+                        0]]))
             ax.set_ylabel(
-                'PC# {} ({:.3f}%)'.format(pcs[1] + 1, self.ev_ratio.data[pcs[
-                    1]]))
+                    'PC# {} ({:.3f}%)'.format(pcs[1] + 1, self.ev_ratio.data[pcs[
+                        1]]))
             ax.set_zlabel(
-                'PC# {} ({:.3f}%)'.format(pcs[2] + 1, self.ev_ratio.data[pcs[
-                    2]]))
+                    'PC# {} ({:.3f}%)'.format(pcs[2] + 1, self.ev_ratio.data[pcs[
+                        2]]))
             axsc = ax.scatter(self.S.masked_data[:, pcs[0]],
                               self.S.masked_data[:, pcs[1]],
                               self.S.masked_data[:, pcs[2]],
@@ -522,11 +520,11 @@ class PCA(HasTraits):
             import matplotlib.patches as mpatches
 
             leg = []
-            for l in labels:
-                i = labels.index(l)
+            for lab in labels:
+                i = labels.index(lab)
                 c = axsc.get_cmap().colors[int(255 / (len(labels) - 1) * i)]
                 leg.append(mpatches.Patch(color=c,
-                                          label=l))
+                                          label=lab))
 
             ax.legend(handles=leg, loc='best')
 
