@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-#
 # ======================================================================================================================
-# Copyright (©) 2015-2020 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
-# See full LICENSE agreement in the root directory
+#  Copyright (©) 2015-2020 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
 # ======================================================================================================================
+
 """
 This module implements the base |NDArray| class.
 
@@ -24,7 +22,6 @@ import re
 import textwrap
 import uuid
 import itertools
-import sys
 
 # ======================================================================================================================
 # Third party imports
@@ -33,25 +30,21 @@ import sys
 from traitlets import List, Unicode, Instance, Bool, Union, Int, HasTraits, default, validate
 from pint.errors import DimensionalityError
 import numpy as np
+import pandas as pd
+from pandas.core.generic import NDFrame, Index
+from traittypes import Array
 
 # ======================================================================================================================
 # local imports
 # ======================================================================================================================
 
-from ...units import Unit, ur, Quantity, set_nmr_context
-from ...core import info_, debug_, error_, warning_, print_
-from ...utils import (TYPE_INTEGER, TYPE_FLOAT, Meta, MaskedConstant, MASKED, NOMASK, INPLACE, is_sequence, is_number,
-                      numpyprintoptions, insert_masked_print, docstrings, SpectroChemPyWarning,
-                      SpectroChemPyDeprecationWarning, deprecated,
-                      make_new_object, convert_to_html, HAS_PANDAS, HAS_XARRAY)
-from ...extern.traittypes import Array
+from spectrochempy.units import Unit, ur, Quantity, set_nmr_context
+from spectrochempy.core import info_, error_, print_
+from spectrochempy.utils import (TYPE_INTEGER, TYPE_FLOAT, Meta, MaskedConstant, MASKED, NOMASK, INPLACE, is_sequence,
+                                 is_number, numpyprintoptions, insert_masked_print, docstrings, SpectroChemPyWarning,
+                                 make_new_object, convert_to_html)
 
-if HAS_PANDAS:
-    import pandas as pd
-    from pandas.core.generic import NDFrame, Index
 
-if HAS_XARRAY:
-    import xarray as xr
 
 # ======================================================================================================================
 # constants
@@ -70,6 +63,7 @@ numpyprintoptions()
 # The basic NDArray class
 # ======================================================================================================================
 
+
 class NDArray(HasTraits):
     """
     The basic |NDArray| object.
@@ -93,14 +87,14 @@ class NDArray(HasTraits):
     _data = Array(allow_none=True)
     _dtype = Instance(np.dtype, allow_none=True)
     _dims = List(Unicode())
-    _mask = Union((Bool(), Array(Bool()), Instance(MaskedConstant) ))
+    _mask = Union((Bool(), Array(Bool()), Instance(MaskedConstant)))
     _labels = Array(allow_none=True)
     _units = Instance(Unit, allow_none=True)
 
     # metadata
     _meta = Instance(Meta, allow_none=True)
     _origin = Unicode()
-    
+
     # Basic NDArray setting
     _copy = Bool(False)  # by defaults we do not copy the data
     # which means that if the same numpy array
@@ -201,17 +195,17 @@ class NDArray(HasTraits):
         self.name = kwargs.pop('name', None)
 
         # process eventual kwargs, adressing HasTrait class
-        super().__init__(**kwargs)
+        # super().__init__(**kwargs)   <-- cause problem of deprecation warning.
 
     # ..................................................................................................................
     def implements(self, name=None):
         """
         Utility to check if the current object implement `NDArray`.
-       
+
         Rather than isinstance(obj, NDArrray) use object.implements('NDArray').
-       
+
         This is useful to check type without importing the module
-       
+
         """
         if name is None:
             return 'NDArray'
@@ -242,9 +236,9 @@ class NDArray(HasTraits):
 
     # ..................................................................................................................
     def __eq__(self, other, attrs=None):
-        
+
         eq = True
-        
+
         if not isinstance(other, NDArray):
             # try to make some assumption to make useful comparison.
             if isinstance(other, Quantity):
@@ -263,24 +257,31 @@ class NDArray(HasTraits):
             else:
                 return False
             return eq
-        
+
         if attrs is None:
             attrs = self.__dir__()
-        
-        #if 'title' in attrs:
+
+        # if 'title' in attrs:
         #    attrs.remove('title')  #TODO: should we use title for comparison?
-        
+
         if 'name' in attrs:
             attrs.remove('name')
-            
+
         for attr in attrs:
             if attr != 'units':
                 sattr = getattr(self, f'_{attr}')
                 if hasattr(other, f'_{attr}'):
                     oattr = getattr(other, f'_{attr}')
+                    # to avoid deprecation warning issue for unequal array
+                    if (sattr is None and oattr is not None):
+                        return False
+                    if (oattr is None and sattr is not None):
+                        return False
+                    if hasattr(oattr, 'size') and hasattr(sattr, 'size') \
+                            and oattr.size != sattr.size:
+                        return False
                     eq &= np.all(sattr == oattr)
                     if not eq:
-                        #debug_(f"attributes `{attr}` are not equals or one is missing: \n{sattr} != {oattr}")
                         return False
                 else:
                     return False
@@ -293,10 +294,10 @@ class NDArray(HasTraits):
                     oattr = other._units
                     if oattr is None:
                         oattr = ur.dimensionless
-                        
+
                     eq &= np.all(sattr == oattr)
                     if not eq:
-                        #debug_(f"attributes `{attr}` are not equals or one is missing: \n{sattr} != {oattr}")
+                        # debug_(f"attributes `{attr}` are not equals or one is missing: \n{sattr} != {oattr}")
                         return False
                 else:
                     return False
@@ -456,7 +457,7 @@ class NDArray(HasTraits):
     # ------------------------------------------------------------------------------------------------------------------
     # Default setting
     # ------------------------------------------------------------------------------------------------------------------
-    
+
     # ..................................................................................................................
     @default('_data')
     def _data_default(self):
@@ -541,7 +542,7 @@ class NDArray(HasTraits):
             # No need to check the validity of the data
             # because the data must have been already
             # successfully initialized for the passed NDArray.data
-            #debug_("init data with data from another NDArray object")
+            # debug_("init data with data from another NDArray object")
             for attr in self.__dir__():
                 try:
                     val = getattr(data, f"_{attr}")
@@ -552,23 +553,23 @@ class NDArray(HasTraits):
                     # some attribute of NDDataset are missing in NDArray
                     pass
 
-        elif HAS_PANDAS and isinstance(data, NDFrame):  # pandas object
-            #debug_("init data with data from pandas NDFrame object")
+        elif isinstance(data, NDFrame):  # pandas object
+            # debug_("init data with data from pandas NDFrame object")
             self._data = data.values
 
-        elif HAS_PANDAS and isinstance(data, Index):  # pandas index object
-            #debug_("init data with data from a pandas Index")
+        elif isinstance(data, Index):  # pandas index object
+            # debug_("init data with data from a pandas Index")
             self._data = data.values
             self._title = data.name
 
         elif isinstance(data, Quantity):
-            #debug_("init data with data from a Quantity object")
+            # debug_("init data with data from a Quantity object")
             self._data = np.array(data.magnitude, subok=True, copy=self._copy)
             self._units = data.units
 
         elif hasattr(data, 'mask'):
             # an object with data and mask attributes
-            #debug_("mask detected - initialize a mask from the passed data")
+            # debug_("mask detected - initialize a mask from the passed data")
             self._data = np.array(data.data, subok=True,
                                   copy=self._copy)
             if isinstance(data.mask, np.ndarray) and \
@@ -613,10 +614,10 @@ class NDArray(HasTraits):
     def dims(self):
         """
         list -  Names of the dimensions
-        
+
         The name of the dimensions are 'x', 'y', 'z'.... depending on the number of dimension.
+
         """
-        
         ndim = self.ndim
         if ndim > 0:
             # if len(self._dims)< ndim:
@@ -630,9 +631,9 @@ class NDArray(HasTraits):
     @dims.setter
     def dims(self, values):
 
-        if isinstance(values, str) and len(values)==1:
+        if isinstance(values, str) and len(values) == 1:
             values = [values]
-            
+
         if not is_sequence(values) or len(values) != self.ndim:
             raise ValueError(f'a sequence of chars with a length of {self.ndim} is expected, but `{values}` '
                              f'has been provided')
@@ -644,14 +645,14 @@ class NDArray(HasTraits):
 
         self._dims = tuple(values)
 
-
     # ..................................................................................................................
     @property
     def dlabel(self):
         """
         str - An user friendly data label.
-        
+
         It's an alias of the `title` property
+
         """
         return self.title
 
@@ -681,9 +682,9 @@ class NDArray(HasTraits):
         """
         if self.data is None:
             return None
-    
+
         return self.data.dtype.itemsize
-    
+
     # ..................................................................................................................
     @property
     def labels(self):
@@ -700,7 +701,7 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     @labels.setter
     def labels(self, labels):
-        
+
         if labels is None:
             return
 
@@ -745,7 +746,7 @@ class NDArray(HasTraits):
     def mask(self):
         """
         |ndarray| (bool) - Mask for the data
-        
+
         """
         if not self.is_masked:
             return NOMASK
@@ -755,7 +756,7 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     @mask.setter
     def mask(self, mask):
-        
+
         if mask is NOMASK or mask is MASKED:
             pass
         elif isinstance(mask, (np.bool_, bool)):
@@ -800,10 +801,10 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     @meta.setter
     def meta(self, meta):
-        
+
         if meta is not None:
             self._meta.update(meta)
-            
+
     # ..................................................................................................................
     @property
     def origin(self):
@@ -811,7 +812,7 @@ class NDArray(HasTraits):
         str - origin of the data
         """
         return self._origin
-    
+
     # ..................................................................................................................
     @origin.setter
     def origin(self, origin):
@@ -822,10 +823,10 @@ class NDArray(HasTraits):
     def title(self):
         """
         str - An user friendly title.
-        
+
         When the title is provided, it can be used for labeling the object,
         e.g., axe title in a matplotlib plot.
-        
+
         """
         if self._title:
             return self._title
@@ -835,7 +836,7 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     @title.setter
     def title(self, title):
-        
+
         if title:
             self._title = title
 
@@ -844,7 +845,7 @@ class NDArray(HasTraits):
     def name(self):
         """
         str - An user friendly name.
-        
+
         When the name is not provided, the `id` of the object is retruned instead
 
         """
@@ -856,10 +857,10 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     @name.setter
     def name(self, name):
-        
+
         if name:
             if self._name:
-                #debug_("Overwriting current name")
+                # debug_("Overwriting current name")
                 pass
             self._name = name
 
@@ -868,14 +869,14 @@ class NDArray(HasTraits):
     def units(self):
         """
         |Unit| - The units of the data.
-        
+
         """
         return self._units
 
     # ..................................................................................................................
     @units.setter
     def units(self, units):
-        
+
         if units is None:
             return
         if isinstance(units, str):
@@ -938,7 +939,7 @@ class NDArray(HasTraits):
         bool - True is the name has been defined
 
         """
-        return not(self.name == self.id)
+        return not (self.name == self.id)
 
     # ..................................................................................................................
     @property
@@ -972,13 +973,13 @@ class NDArray(HasTraits):
 
     # ..................................................................................................................
     @property
-    def  is_1d(self):
+    def is_1d(self):
         """
         bool - True if the `data` array has only one dimension
 
         """
         return self.ndim == 1
-    
+
     # ..................................................................................................................
     @property
     def is_empty(self):
@@ -1116,7 +1117,8 @@ class NDArray(HasTraits):
     @property
     def umasked_data(self):
         """
-        |ndarray|, dtype:object - The actual array with mask and unit 
+        |ndarray|, dtype:object - The actual array with mask and unit
+
         (Readonly property).
         """
         if self._data is None:
@@ -1155,7 +1157,7 @@ class NDArray(HasTraits):
     def T(self):
         """
         |NDArray| - Transposed array.
-        
+
         The same object is returned if `ndim` is less than 2.
 
         """
@@ -1164,7 +1166,7 @@ class NDArray(HasTraits):
     # ------------------------------------------------------------------------------------------------------------------
     # Public methods
     # ------------------------------------------------------------------------------------------------------------------
-    
+
     # ..................................................................................................................
     def asfortranarray(self):
 
@@ -1221,7 +1223,6 @@ class NDArray(HasTraits):
 
             except ValueError:
                 # ensure that if deepcopy do not work, a shadow copy can be done
-                _attr = cpy.copy(getattr(self, f"_{attr}"))
                 _attr = do_copy(getattr(self, f"_{attr}"))
                 setattr(new, f"_{attr}", _attr)
 
@@ -1243,7 +1244,7 @@ class NDArray(HasTraits):
             or 'dims'
         negative_axis : bool, optional, default=False.
             If True a negative index is returned for the axis value (-1 for the last dimension, etc...)
-            
+
         Returns
         -------
         axis : int
@@ -1258,10 +1259,10 @@ class NDArray(HasTraits):
         allows_none = kwargs.get('allows_none', False)
         if axis is None and dims is None and allows_none:
             return None, None
-        axis = axis[0] if axis else -1 # None
+        axis = axis[0] if axis else -1  # None
         dim = self.dims[axis]
         if axis is not None and kwargs.get('negative_axis', False):
-            if axis>=0:
+            if axis >= 0:
                 axis = axis - self.ndim
         return axis, dim
 
@@ -1327,7 +1328,7 @@ class NDArray(HasTraits):
         """
         try:
             other.to(self.units, inplace=False)
-        except ValueError:
+        except DimensionalityError:
             return False
         return True
 
@@ -1348,7 +1349,7 @@ class NDArray(HasTraits):
         -------
         object
             same object with new units.
-            
+
         See Also
         --------
         to
@@ -1397,7 +1398,7 @@ class NDArray(HasTraits):
             s = np.array(new.shape)
             dims = np.argwhere(s == 1).squeeze().tolist()
         axis = self._get_dims_index(dims)
-        #debug_(f"axis:{axis}<-dims:{dims}")
+        # debug_(f"axis:{axis}<-dims:{dims}")
 
         # recompute new dims
         for i in axis[::-1]:
@@ -1419,7 +1420,6 @@ class NDArray(HasTraits):
         """
         Interchange two dims of a NDArray.
 
-
         Parameters
         ----------
         dim1 : int or str
@@ -1431,7 +1431,7 @@ class NDArray(HasTraits):
         Returns
         -------
         %(generic_method.returns)s
-        
+
         See Also
         --------
         transpose
@@ -1470,7 +1470,6 @@ class NDArray(HasTraits):
         force : bool, optional, default=False
             If True the change of units is forced, even for incompatible units
 
- 
          Returns
         -------
         %(generic_method.returns.object)s
@@ -1525,7 +1524,7 @@ class NDArray(HasTraits):
             units = ur.Unit(other)
         if self.has_units:
             try:
-                if new.origin in ['bruker',]:
+                if new.origin in ['bruker', ]:
                     # its nmr data
                     set_nmr_context(new.meta.larmor)
                     with ur.context('nmr'):
@@ -1564,22 +1563,17 @@ class NDArray(HasTraits):
             DataFrame for multidimentional arrays
 
         """
-        if HAS_PANDAS:
-            import pandas as pd
-        else:
-            raise ImportError('Cannot perform this conversion as Pandas is not installed.')
-    
         if self.is_empty and not self.is_labeled:
             raise ValueError('no valid index for a 0-dimensional object.')
-    
-        if self.ndim==1:
+
+        if self.ndim == 1:
             if self.has_units:
-                out = pd.MultiIndex.from_product([[str(self.units)],self.data], names=['units', self.title])
+                out = pd.MultiIndex.from_product([[str(self.units)], self.data], names=['units', self.title])
             else:
                 out = pd.Index(self.data, name=self.title)
         else:
             raise NotImplementedError('Not yet implemented')
-        
+
         return out
 
     # ..................................................................................................................
@@ -1597,15 +1591,14 @@ class NDArray(HasTraits):
             index or names must match the number of dimensions.
         %(generic_method.parameters.inplace)s
 
- 
         Returns
         -------
         %(generic_method.returns)s
-        
+
         See Also
         --------
         swapaxes
-        
+
         """
         if not inplace:
             new = self.copy()
@@ -1626,6 +1619,19 @@ class NDArray(HasTraits):
 
         return new
 
+    def astype(self, dtype=None, **kwargs):
+        """
+        Cast the data to a specified type.
+
+        Parameters
+        ----------
+        dtype : str or dtype
+            typecode or data-type to which the array is cast.
+
+        """
+        self.data = self.data.astype(dtype, **kwargs)
+        return self
+
     # ------------------------------------------------------------------------------------------------------------------
     # private methods
     # ------------------------------------------------------------------------------------------------------------------
@@ -1670,7 +1676,7 @@ class NDArray(HasTraits):
     # ..................................................................................................................
     def _str_value(self, sep='\n', ufmt=' {:~K}',
                    header='         data: ... \n'):
-        prefix = ['']
+        # prefix = ['']
         if self.is_empty and 'data: ...' not in header:
             return header + '{}'.format(textwrap.indent('empty', ' ' * 9))
         elif self.is_empty:
@@ -1733,15 +1739,17 @@ class NDArray(HasTraits):
 
         if not self.is_empty:
 
-            if self._data is not None:
-                data = self.umasked_data
-            else:
-                # no data but labels
-                data = self.get_labels()
+            # if self._data is not None:
+            #    data = self.umasked_data
+            # else:
+            #    # no data but labels
+            #    data = self.get_labels()
+
+            if self._data is None:
                 print_unit = False
 
-            if isinstance(data, Quantity):
-                data = data.magnitude
+            # if isinstance(data, Quantity):
+            #    data = data.magnitude                   # TODO:   Check why it is not used???
 
             if print_unit:
                 units = ' {:~K}'.format(self.units) if self.has_units else ' unitless'
@@ -1764,8 +1772,8 @@ class NDArray(HasTraits):
         if by == 'value':
             args = np.argsort(self.data)
         elif 'label' in by and not self.is_labeled:
-            by = 'value'
-            pos = None
+            # by = 'value'
+            # pos = None
             warnings.warn('no label to sort, use `value` by default', SpectroChemPyWarning)
             args = np.argsort(self.data)
         elif 'label' in by and self.is_labeled:
@@ -1782,7 +1790,7 @@ class NDArray(HasTraits):
                 labels = self._labels[..., pos]
             args = np.argsort(labels)
         else:
-            by = 'value'
+            # by = 'value'
             warnings.warn('parameter `by` should be set to `value` or `label`, use `value` by default',
                           SpectroChemPyWarning)
             args = np.argsort(self.data)
@@ -1795,17 +1803,17 @@ class NDArray(HasTraits):
         # Return the index of a location (label or values such as coordinates) along a 1D array.
         # Do not apply for multidimensionnal arrays (ndim>1)
         if self.ndim > 1:
-            raise NotImplemented(f'not implemented for {type(self).__name__} objects which are not 1-dimensional '
-                                 f'(current ndim:{self.ndim})')
+            raise NotImplementedError(f'not implemented for {type(self).__name__} objects which are not 1-dimensional '
+                                      f'(current ndim:{self.ndim})')
 
         if self.is_empty and not self.is_labeled:
-                
-                raise IndexError(f'Could not find this location: {loc} on an empty array')
-        
+
+            raise IndexError(f'Could not find this location: {loc} on an empty array')
+
         else:
-            
+
             data = self._data
-    
+
             if is_number(loc):
                 # get the index of a given values
                 error = None
@@ -1819,15 +1827,15 @@ class NDArray(HasTraits):
                     return index
                 else:
                     return index, error
-            
+
             elif is_sequence(loc):
                 # TODO: is there a simpler way to do this with numpy functions
                 index = []
-                for l in loc:
-                    index.append((np.abs(data - l)).argmin())
+                for lo in loc:
+                    index.append((np.abs(data - lo)).argmin())
                     # TODO: add some precison to this result
                 return index
-    
+
             elif isinstance(loc, datetime):
                 # not implemented yet
                 raise NotImplementedError("datetime as location is not yet impemented")  # TODO: date!
@@ -1936,7 +1944,7 @@ class NDArray(HasTraits):
                 if stop != start:
                     stop = stop + 1  # to include last loc or label index
             if step is not None and not isinstance(step, (int, np.int_, np.int64)):
-                raise NotImplemented('step in location slicing is not yet possible.')
+                raise NotImplementedError('step in location slicing is not yet possible.')
                 # TODO: we have may be a special case with datetime
                 # step = 1
         if step is None:
@@ -1965,10 +1973,12 @@ class NDArray(HasTraits):
         def ellipsisinkeys(keys):
             try:
                 # Ellipsis
+                if isinstance(keys[0], np.ndarray):
+                    return False
                 test = Ellipsis in keys
             except ValueError as e:
                 if e.args[0].startswith('The truth '):
-                    # probably an array of index (Fancy indexing)
+                    # probably an array of index (Fancy indexing)  # should not happen any more with the test above
                     test = False
             return test
 
@@ -2010,7 +2020,7 @@ class NDArray(HasTraits):
 
         return new
 
-    # # ..................................................................................................................
+    # ..................................................................................................................
     # def _take(self, indices):
     #     # get a ndarray with passed indices
     #     new = self.copy()
