@@ -32,8 +32,8 @@ import warnings
 
 import numpy as np
 import matplotlib.pyplot as plt
-from numpy.compat import asbytes, asstr
-from numpy.lib.format import write_array, MAGIC_PREFIX
+from numpy.compat import asstr
+from numpy.lib.format import write_array
 from numpy.lib.npyio import zipfile_factory, NpzFile
 from traitlets import HasTraits, Unicode
 
@@ -41,14 +41,14 @@ from traitlets import HasTraits, Unicode
 # local import
 # ----------------------------------------------------------------------------------------------------------------------
 
-from .ndarray import NDArray
-from .ndcoord import Coord
-from .ndcoordset import CoordSet
-from ...utils import SpectroChemPyWarning
-from ...utils.meta import Meta
-from ...units import Unit, Quantity
-from ...core import general_preferences as prefs
-from ...core import info_, debug_, error_, warning_
+# from .ndarray import NDArray
+from spectrochempy.core.dataset.ndcoord import Coord
+from spectrochempy.core.dataset.ndcoordset import CoordSet
+from spectrochempy.utils import SpectroChemPyWarning
+from spectrochempy.utils.meta import Meta
+from spectrochempy.units import Unit, Quantity
+from spectrochempy.core import general_preferences as prefs
+# from spectrochempy.core import info_, debug_, error_, warning_
 
 
 # ==============================================================================
@@ -63,7 +63,7 @@ class NDIO(HasTraits):
 
     """
 
-    _filename = Unicode
+    _filename = Unicode()
 
     @property
     def filename(self):
@@ -185,10 +185,9 @@ class NDIO(HasTraits):
                         write_array(fid, np.asanyarray(val), allow_pickle=True)
 
                     zipf.write(tmpfile, arcname=level + key + '.npy')
-                    
 
                 elif isinstance(val, CoordSet):
-                    
+
                     for v in val._coords:
                         _objnames = dir(v)
                         if isinstance(v, Coord):
@@ -282,7 +281,7 @@ class NDIO(HasTraits):
             filename, ext = os.path.splitext(fid)
             try:
                 return cls.read(fid, protocol=ext[1:])
-            except:
+            except Exception:
                 pass
 
         if isinstance(fid, str):
@@ -299,13 +298,13 @@ class NDIO(HasTraits):
                     # cast to file in the testdata directory
                     # TODO: add possibility to search in several directory
                     fid = open(filename, 'rb')
-                except:
+                except Exception:
                     if not filename.endswith('.scp'):
                         filename = filename + '.scp'
                     try:
                         # try again
                         fid = open(filename, 'rb')
-                    except:
+                    except Exception:
                         # try the working directory
                         filename = os.path.join(os.getcwd(), filename)
                         try:
@@ -337,13 +336,13 @@ class NDIO(HasTraits):
                     coords = {}
                 els = key.split('_')
                 dim = els[1]
-                idx = "_"+els[3]
+                idx = "_" + els[3]
                 if dim not in coords.keys():
-                    coords[dim] = CoordSet({idx:Coord()})
+                    coords[dim] = CoordSet({idx: Coord()})
                 if idx not in coords[dim].names:
-                    coords[dim].set(**{idx:Coord()})
+                    coords[dim].set(**{idx: Coord()})
                 setattr(coords[dim][idx], "_%s" % els[4], val)
-            
+
             elif key == "pars.json":
                 pars = json.loads(asstr(val))
             else:
@@ -405,7 +404,7 @@ class NDIO(HasTraits):
                 elif key.endswith("references"):
                     setattributes(coords[dim], "references", val)
                 else:
-                    idx = "_"+els[3]
+                    idx = "_" + els[3]
                     setattributes(coords[dim][idx], els[4], val)
             else:
 
@@ -427,7 +426,7 @@ class NDIO(HasTraits):
              **kwargs
              ):
         """
-        Load a list of dataset objects saved as a pickle files ( e.g., '\*.scp' file).
+        Load a list of dataset objects saved as a pickle files ( e.g., '*.scp' file).
 
         It's a class method, that can be used directly on the class,
         without prior opening of a class instance.
@@ -437,7 +436,7 @@ class NDIO(HasTraits):
         fid : list of `str` or `file` objects
             The names of the files to read (or the file objects).
         protocol : str, optional, default:'scp'
-            The default type for saving.
+            The default type for loading.
         directory : str, optional, default:`prefs.datadir`
             The directory from where to load the file.
         kwargs : optional keyword parameters.
@@ -476,7 +475,7 @@ class NDIO(HasTraits):
         if not isinstance(fid, (list, tuple)):
             files = [fid]
 
-        for f in files:
+        for f in files:  # lgtm [py/iteration-string-and-sequence]
             nd = NDIO._load(cls, fid=f, protocol=protocol, directory=directory, **kwargs)
             datasets.append(nd)
 
@@ -497,10 +496,12 @@ class NDIO(HasTraits):
         Parameters
         ----------
         filename : str
-            The path to the file to be read
+            The path to the file to be read. If it is not provided,
+            at least a protocol must be given.
         protocol : str
             Protocol used for reading. If not provided, the correct protocol
             is evaluated from the file name extension.
+            Existing protocol: 'scp', 'omnic', 'opus', 'matlab', 'jdx', 'csv', ...
         kwargs : optional keyword parameters
             Any additional keyword to pass to the actual reader
 
@@ -510,13 +511,14 @@ class NDIO(HasTraits):
 
         """
 
-        if filename is None:
-            raise ValueError('read method require a parameter ``filename``!')
-
         protocol = kwargs.pop('protocol', None)
         sortbydate = kwargs.pop('sortbydate', True)
 
-        if protocol is None:
+        if filename is None and protocol is None:
+            raise ValueError('read method require a parameter ``filename`` '
+                             'or at least a protocol such as `scp`, `omnic`, ... !')
+
+        if filename is not None and protocol is None:
             # try to estimate the protocol from the file name extension
             _, extension = os.path.splitext(filename)
             if len(extension) > 0:
@@ -574,11 +576,9 @@ class NDIO(HasTraits):
             _writer = getattr(self, 'write_{}'.format(protocol))
             return _writer(filename, **kwargs)
 
-        except:
+        except Exception:
 
-            raise AttributeError('The specified writter '
-                                 'for protocol `{}` was not found!'.format(
-                protocol))
+            raise AttributeError(f'The specified writter for protocol `{protocol}` was not found!')
 
 
 # make some methods accessible from the main scp API
