@@ -28,7 +28,7 @@ import warnings
 
 from cycler import cycler
 import matplotlib as mpl
-from mpl_toolkits.mplot3d import Axes3D
+# from mpl_toolkits.mplot3d import Axes3D
 from matplotlib import pyplot as plt
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 from traitlets import Dict, HasTraits, Instance, default
@@ -38,16 +38,16 @@ from traitlets import Dict, HasTraits, Instance, default
 from spectrochempy.utils import (is_sequence, SpectroChemPyDeprecationWarning,
                                  docstrings, NBlack, NBlue, NGreen, NRed, get_figure)
 from spectrochempy.core import general_preferences, project_preferences
-from ...core import info_, debug_, error_, warning_
-
-prefs = general_preferences
-
+from spectrochempy.core import error_
 
 from spectrochempy.core.plotters.plot1d import plot_1D
 from spectrochempy.core.plotters.plot3d import plot_3D
 from spectrochempy.core.plotters.plot2d import plot_2D
 from spectrochempy.utils.meta import Meta
-from spectrochempy.utils import deprecated
+
+# from spectrochempy.utils import deprecated
+
+prefs = general_preferences
 
 
 # ======================================================================================================================
@@ -65,7 +65,7 @@ class NDPlot(HasTraits):
     # The figure on which this dataset can be plotted
     _fig = Instance(plt.Figure, allow_none=True)
 
-    # The axes on which this dataset and other elements such as projections 
+    # The axes on which this dataset and other elements such as projections
     # and colorbar can be plotted
     _ndaxes = Dict(Instance(plt.Axes))
 
@@ -139,7 +139,7 @@ class NDPlot(HasTraits):
         if _plotter is None:
             # no plotter found
             error_('The specified plotter for method '
-                      '`{}` was not found!'.format(method))
+                   '`{}` was not found!'.format(method))
             raise IOError
 
         # Execute the plotter
@@ -395,8 +395,7 @@ class NDPlot(HasTraits):
         loc = kwargs.get("legend", None)
         if loc:
             origin.ndaxes['main'].legend(loc=loc)
-        
-        
+
         # Additional matplotlib commands on the current plot
         # ---------------------------------------------------------------------
 
@@ -582,10 +581,13 @@ def _set_figure_style(**kwargs):
     except OSError:
         # scpy not found! may be due to a failing installation
         # make a basic style here
-        # get the local version:
-        plt.style.use(os.path.join(prefs.stylesheets, 'scpy.mplstyle'))
+        # get the local version if it exists:
+        try:
+            plt.style.use(os.path.join(prefs.stylesheets, 'scpy.mplstyle'))
+        except OSError:
+            pass
 
-    # now get the required style form args
+    # now get the required style from args
     style = kwargs.get('style', None)
 
     if style:
