@@ -12,7 +12,7 @@ In this module, we define basic functions adapted from numpy but able to handle
 our NDDataset objects
 
 """
-__all__ = ['diag', 'dot', 'empty', 'empty_like', 'zeros', 'zeros_like', 'ones',
+__all__ = ['diag', 'dot', 'empty', 'empty_like', 'zeros', 'eye', 'identity', 'zeros_like', 'ones',
            'ones_like', 'full', 'full_like']
 
 # ----------------------------------------------------------------------------------------------------------------------
@@ -21,8 +21,8 @@ __all__ = ['diag', 'dot', 'empty', 'empty_like', 'zeros', 'zeros_like', 'ones',
 
 import numpy as np
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.ndcoordset import CoordSet
-from spectrochempy.core.dataset.ndcoord import Coord
+# from spectrochempy.core.dataset.ndcoordset import CoordSet
+# from spectrochempy.core.dataset.ndcoord import Coord
 from spectrochempy.utils import NOMASK, make_new_object
 
 
@@ -187,6 +187,81 @@ def ones(shape, dtype=None, **kwargs):
     return NDDataset(np.ones(shape, dtype=np.dtype(dtype)), **kwargs)
 
 
+def identity(N, dtype=None, **kwargs):
+    """
+    Return the identity array.
+
+    The identity array is a square array with ones on
+    the main diagonal.
+
+    Parameters
+    ----------
+    N : int
+        Number of rows (and columns) in `n` x `n` output.
+    dtype : data-type, optional
+        Data-type of the output.  Defaults to ``float``.
+
+    Returns
+    -------
+    out : nddataset
+        `n` x `n` array with its main diagonal set to one,
+        and all other elements 0.
+
+    Examples
+    --------
+    >>> scp.identity(3).data
+    array([[1.,  0.,  0.],
+           [0.,  1.,  0.],
+           [0.,  0.,  1.]])
+
+    """
+    return eye(N, dtype=dtype, **kwargs)
+
+
+def eye(N, M=None, k=0, dtype=float, order='C', **kwargs):
+    """
+    Return a 2-D array with ones on the diagonal and zeros elsewhere.
+    Parameters
+    ----------
+    N : int
+      Number of rows in the output.
+    M : int, optional
+      Number of columns in the output. If None, defaults to `N`.
+    k : int, optional
+      Index of the diagonal: 0 (the default) refers to the main diagonal,
+      a positive value refers to an upper diagonal, and a negative value
+      to a lower diagonal.
+    dtype : data-type, optional
+      Data-type of the returned array.
+    order : {'C', 'F'}, optional
+        Whether the output should be stored in row-major (C-style) or
+        column-major (Fortran-style) order in memory.
+
+    Returns
+    -------
+    I : NDDataset of shape (N,M)
+      An array where all elements are equal to zero, except for the `k`-th
+      diagonal, whose values are equal to one.
+
+    See Also
+    --------
+    identity : equivalent function with k=0.
+    diag : diagonal 2-D NDDataset from a 1-D array specified by the user.
+
+    Examples
+    --------
+    >>> np.eye(2, dtype=int)
+    array([[1, 0],
+           [0, 1]])
+    >>> np.eye(3, k=1)
+    array([[0.,  1.,  0.],
+           [0.,  0.,  1.],
+           [0.,  0.,  0.]])
+
+    """
+    return NDDataset(np.eye(N, M, k, dtype, order), **kwargs)
+
+
 def zeros_like(a, dtype=None, ):
     """
     Return a |NDDataset| of zeros with the same shape and type as a given
@@ -224,7 +299,6 @@ def zeros_like(a, dtype=None, ):
     NDDataset: [[       0,        0,        0],
                 [       0,        0,        0]] s
 
-
     """
     new = a.copy()
     if dtype:
@@ -386,7 +460,6 @@ def dot(a, b, strict=True, out=None):
     .. note::
       Works only with 2-D arrays at the moment.
 
-
     Parameters
     ----------
     a, b : masked_array_like
@@ -422,9 +495,9 @@ def dot(a, b, strict=True, out=None):
     #                     ' of type {} has been provided'.format(
     #         type(b).__name__))
 
-    #TODO: may be we can be less strict, and allow dot products with
+    # TODO: may be we can be less strict, and allow dot products with
     #      different kind of objects, as far they are numpy-like arrays
-    
+
     if not isinstance(a, NDDataset) and not isinstance(a, NDDataset):
         # must be between numpy object or something non valid. Let numpy deal with this
         return np.dot(a, b)
@@ -436,7 +509,7 @@ def dot(a, b, strict=True, out=None):
     if not isinstance(b, NDDataset):
         # try to cast to NDDataset
         b = NDDataset(b)
-        
+
     data = np.ma.dot(a.masked_data, b.masked_data)
     mask = data.mask
     data = data.data
@@ -449,7 +522,7 @@ def dot(a, b, strict=True, out=None):
         coordx = getattr(b, b.dims[1])
     else:
         coordx = None
-    
+
     history = 'Dot product between %s and %s' % (a.name, b.name)
 
     # make the output
@@ -465,7 +538,7 @@ def dot(a, b, strict=True, out=None):
         new.units = a.units
     else:
         new.units = a.units * b.units
-    
+
     return new
 
 
@@ -480,7 +553,7 @@ def diag(dataset, k=0):
     are using.
 
     Adapted from numpy (licence #TO ADD)
-    
+
     Parameters
     ----------
     v : array_like
@@ -493,8 +566,6 @@ def diag(dataset, k=0):
     out : ndarray
         The extracted diagonal or constructed diagonal array.
 
-    
-    
     """
     # TODO: fix this - other diagonals
     # k : int, optional
@@ -505,8 +576,8 @@ def diag(dataset, k=0):
     # check if we have the correct input
     # ------------------------------------------------------------------------------------------------------------------
 
-    if not isinstance(dataset, NDDataset) :
-    # must be anumpy object or something non valid. Let numpy deal with this
+    if not isinstance(dataset, NDDataset):
+        # must be anumpy object or something non valid. Let numpy deal with this
         return np.diag(dataset)
 
     s = dataset.data.shape
@@ -522,11 +593,11 @@ def diag(dataset, k=0):
             mask = m | m.T
         coords = None
         if dataset.coords is not None:
-            coords = dataset.coords # [dataset.coords[0]] * 2
+            coords = dataset.coords  # [dataset.coords[0]] * 2
         history = 'Diagonal array build from the 1D dataset'
         units = dataset.units
         dims = dataset.dims * 2
-        
+
     elif len(s) == 2:
         # extract a diagonal
         # ------------------
@@ -541,7 +612,7 @@ def diag(dataset, k=0):
         history = 'Diagonal of rank %d extracted from original dataset' % k
         units = dataset.units
         dims = dataset.dims[-1]
-        
+
     else:
         raise ValueError("Input must be 1- or 2-d.")
 
@@ -553,7 +624,7 @@ def diag(dataset, k=0):
     new.history = history
     new.units = units
     new.dims = dims
-    
+
     if coords:
         new.set_coords(coords)
 
