@@ -140,9 +140,9 @@ def plot_multiple(datasets, method='scatter', pen=True,
     commands = kwargs.get('commands', [])
     kwargs['commands'] = []
     clear = kwargs.pop('clear', True)
-    legend = kwargs.pop('legend', None) # remove 'legend' from kwargs before calling plot
-                                        # else it will generate a conflict
-    
+    legend = kwargs.pop('legend', None)  # remove 'legend' from kwargs before calling plot
+    # else it will generate a conflict
+
     for s in datasets:  # , colors, markers):
 
         ax = s.plot(method=method,
@@ -158,8 +158,8 @@ def plot_multiple(datasets, method='scatter', pen=True,
 
     # scale all plots
     if legend is not None:
-        leg = ax.legend(ax.lines, labels, shadow=True, loc=legend,
-                        frameon=True, facecolor='lightyellow')
+        _ = ax.legend(ax.lines, labels, shadow=True, loc=legend,
+                      frameon=True, facecolor='lightyellow')
 
     # now we can output the final figure
     kw = {'output': output, 'commands': commands}
@@ -265,7 +265,7 @@ def plot_1D(dataset, **kwargs):
     # make a copy
     # ------------------------------------------------------------------------------------------------------------------
     new = dataset.copy()  # Do we need a copy?
-    new = new.squeeze()   # and squeeze it
+    new = new.squeeze()  # and squeeze it
 
     # If we are in the GUI, we will plot on a widget: but which one?
     # ------------------------------------------------------------------------------------------------------------------
@@ -360,10 +360,10 @@ def plot_1D(dataset, **kwargs):
     xsize = new.size
     if x is not None and (not x.is_empty or x.is_labeled):
         xdata = x.data
-        discrete_data = False
+        # discrete_data = False
         if not np.any(xdata):
             if x.is_labeled:
-                discrete_data = True
+                # discrete_data = True
                 # take into account the fact that sometimes axis have just labels
                 xdata = range(1, len(x.labels) + 1)
     else:
@@ -387,7 +387,7 @@ def plot_1D(dataset, **kwargs):
 
     # plot_lines
     # ------------------------------------------------------------------------------------------------------------------
-    label = kwargs.get('label',None)
+    label = kwargs.get('label', None)
     if scatterpen:
         # pen + scatter
         line, = ax.plot(xdata, zdata.T,
@@ -417,7 +417,7 @@ def plot_1D(dataset, **kwargs):
         # bar only
         line = ax.bar(xdata, zdata.squeeze(), color=color,
                       edgecolor='k', align='center', label=label)
-        barwidth = line[0].get_width()
+        # barwidth = line[0].get_width()
 
     if show_complex and pen:
         # add the imaginaly part for pen only plot
