@@ -15,10 +15,11 @@ import numpy as np
 import datetime as datetime
 from warnings import warn
 
-from ..dataset.nddataset import NDDataset
-from ..dataset.ndcoordset import CoordSet
-from ..dataset.ndcoord import Coord
-from ...utils import is_sequence, docstrings
+from spectrochempy.core.dataset.nddataset import NDDataset
+# from spectrochempy.core.dataset.ndcoordset import CoordSet
+from spectrochempy.core.dataset.ndcoord import Coord
+from spectrochempy.utils import docstrings    # , is_sequence
+
 
 @docstrings.dedent
 def concatenate(*datasets, **kwargs):
@@ -85,12 +86,12 @@ def concatenate(*datasets, **kwargs):
             datasets = datasets[0]
 
     # try to cast of dataset to NDDataset
-    for dataset in datasets:
-        if not isinstance(dataset, NDDataset):
+    for i, item in enumerate(datasets):
+        if not isinstance(item, NDDataset):
             try:
-                dataset = NDDataset(dataset)
-            except:
-                raise TypeError(f"Only instance of NDDataset can be concatenated, not {type(dataset).__name__}, "
+                datasets[i] = NDDataset(item)
+            except Exception:
+                raise TypeError(f"Only instance of NDDataset can be concatenated, not {type(item).__name__}, "
                                 f"but casting to this type failed. ")
 
     # a flag to force stacking of dataset instead of the default concatenation
@@ -107,8 +108,8 @@ def concatenate(*datasets, **kwargs):
     # check if data shapes are compatible (all dimension must have the same size
     # except the one to be concatenated)
     rshapes = []
-    for dataset in datasets:
-        sh = list(dataset.shape)
+    for item in datasets:
+        sh = list(item.shape)
         if len(sh) > 1:
             del sh[axis]
         rshapes.append(sh)
@@ -147,34 +148,34 @@ def concatenate(*datasets, **kwargs):
     # get the coordss
     coordss = [dataset.coords for dataset in datasets]
 
-    def check_coordinates(coordss, force_stack):
-
-        # We will call this only in case of problems because it takes a lot of time
-
-        # how many different coordss
-        coordss = set(coordss)
-        if len(coordss) == 1 and force_stack:
-            # nothing to do (all datasets have the same coords and so are
-            # perfectly compatibles for stacking)
-            pass
-
-        else:
-            for i, cs in enumerate(zip(*coordss)):
-
-                axs = set(cs)
-                axref = axs.pop()
-                for ax in axs:
-                    # we expect compatible units
-                    if not ax.is_units_compatible(axref):
-                        raise ValueError(
-                            "units of the dataset's axis are not compatible"
-                        )
-                    if i != axis and ax.size != axref.size:
-                        # and same size for the non-concatenated axis
-                        raise ValueError(
-                            "size of the non-concatenated dimension must be "
-                            "identical"
-                        )
+    # def check_coordinates(coordss, force_stack):
+    #
+    #     # We will call this only in case of problems because it takes a lot of time
+    #
+    #     # how many different coordss
+    #     coordss = set(coordss)
+    #     if len(coordss) == 1 and force_stack:
+    #         # nothing to do (all datasets have the same coords and so are
+    #         # perfectly compatibles for stacking)
+    #         pass
+    #
+    #     else:
+    #         for i, cs in enumerate(zip(*coordss)):
+    #
+    #             axs = set(cs)
+    #             axref = axs.pop()
+    #             for ax in axs:
+    #                 # we expect compatible units
+    #                 if not ax.is_units_compatible(axref):
+    #                     raise ValueError(
+    #                         "units of the dataset's axis are not compatible"
+    #                     )
+    #                 if i != axis and ax.size != axref.size:
+    #                     # and same size for the non-concatenated axis
+    #                     raise ValueError(
+    #                         "size of the non-concatenated dimension must be "
+    #                         "identical"
+    #                     )
 
     # concatenate or stack the data array + mask
     # ------------------------------------------------------------------------------------------------------------------
@@ -210,7 +211,6 @@ def concatenate(*datasets, **kwargs):
                 # at least one of the coord is labeled
                 is_labeled = True
                 break
-                
 
         if is_labeled:
             labels = []
@@ -242,7 +242,7 @@ def concatenate(*datasets, **kwargs):
             out.author = out.author + ' & ' + dataset.author
 
         out.description += ', {}'.format(dataset.name)
-        
+
     out.description += ' )'
     out._date = out._modified = datetime.datetime.now()
     out._history = [str(out.date) + ': Created by %s' % thist]
