@@ -10,9 +10,9 @@
 
 __all__ = ["fft", "ifft"]
 
-__dataset_methods__  = __all__
+__dataset_methods__ = __all__
 
-#======================================================================================================================
+# ======================================================================================================================
 # Standard python imports
 # ======================================================================================================================
 import re
@@ -25,10 +25,12 @@ import numpy as np
 # ======================================================================================================================
 # Local imports
 # ======================================================================================================================
-from ...extern.nmrglue.process.proc_base import largest_power_of_2, zf_size
+
+from nmrglue.process.proc_base import largest_power_of_2, zf_size
 from .. import error_
 from ...units import ur
 
+
 def ifft(dataset, size=None, inplace=False, **kwargs):
     r"""
     Apply inverse fast fourier transform.
@@ -82,76 +84,76 @@ def fft(dataset, size=None, sizeff=None, inv=False, inplace=False, dim=-1, ppm=T
 
     """
     # datatype
-    is_nmr = dataset.origin in ["bruker",]
-    
+    is_nmr = dataset.origin in ["bruker", ]
+
     # On which axis do we want to apodize? (get axis from arguments)
     axis, dim = dataset.get_axis(dim, negative_axis=True)
-    
+
     # The last dimension is always the dimension on which we apply the fourier transform.
     # If needed, we swap the dimensions to be sure to be in this situation
-    
+
     swaped = False
     if axis != -1:
         dataset.swapaxes(axis, -1, inplace=True)  # must be done in  place
         swaped = True
-    
+
     # select the last coordinates
     lastcoord = dataset.coords[dim]
-    
+
     if (not inv and lastcoord.units.dimensionality != '[time]'):
         error_('fft apply only to dimensions with [time] dimensionality\n'
                'fft processing was thus cancelled')
         return dataset
-    
+
     elif (inv and lastcoord.units.dimensionality != '1/[time]' and lastcoord.units != 'ppm'):
         error_('ifft apply only to dimensions with [frequency] dimensionality or with ppm units\n'
                ' ifft processing was thus cancelled')
         return dataset
-    
-    elif dataset.is_masked :
+
+    elif dataset.is_masked:
         error_('current fft or ifft processing does not support masked data as input.\n processing was thus cancelled')
-        
+
     # TODO: other tests data spacing and so on.
 
     # output dataset inplace or not
-    if not inplace:           # default
+    if not inplace:  # default
         new = dataset.copy()  # copy to be sure not to modify this dataset
     else:
-        new = dataset         #
+        new = dataset  #
 
     # Can we use some metadata as for NMR spectra
     if is_nmr and not inv:
         td = dataset.meta.td[-1]
     else:
         td = lastcoord.size
-        
+
     # if no size (or si) parameter then use the size of the data (size not used for inverse transform
     if size is None or inv:
         size = kwargs.get('si', td)
 
     # we default to the closest power of two larger of the data size
     size = largest_power_of_2(size)
-        
+
     # do we have an effective td to apply
     tdeff = sizeff
     if tdeff is None:
         tdeff = kwargs.get("tdeff", td)
-    
-    if tdeff is None or tdeff<5 or tdeff>size:
+
+    if tdeff is None or tdeff < 5 or tdeff > size:
         tdeff = size
-        
+
     # Eventually apply the effective size
-    new[...,tdeff:] = 0.
-    
+    new[..., tdeff:] = 0.
+
     # should we work on complex data
     iscomplex = new.is_complex
-    
+
     # if we are in NMR we have an additional complication due to the mode
     # of acquisition (sequential mode when ['QSEQ','TPPI','STATES-TPPI'])
     encoding = None
     if is_nmr and not inv:
         encoding = new.meta.encoding[-1]
-    
+
     # perform the fft
     if iscomplex and encoding in ['QSIM', 'DQD']:
         data = zf_size(new.data, size)
@@ -163,49 +165,49 @@ def fft(dataset, size=None, sizeff=None, inv=False, inplace=False, dim=-1, ppm=T
         data = np.fft.ifft(data)
     else:
         raise NotImplementedError(encoding)
-    
+
     # We need here to create a new dataset with new shape and axis
     new._data = data
-    new.mask = False # TODO: make a test on mask - should be none before fft!
-    
+    new.mask = False  # TODO: make a test on mask - should be none before fft!
+
     # create new coordinates for the transformed data
-    
+
     if is_nmr:
         sfo1 = new.meta.sfo1[-1]
         bf1 = new.meta.bf1[-1]
         sf = new.meta.sf[-1]
         sw = new.meta.sw_h[-1]
-        
+
     else:
         sfo1 = 1.0 * ur.Hz
         bf1 = sfo1
         sf = 0 * ur.Hz
         dw = lastcoord.spacing
         sw = 1. / dw
-        
+
     if not inv:
         # time to frequency
         sizem = max(size - 1, 1)
         deltaf = -sw / sizem
         first = sfo1 - sf - deltaf * sizem / 2.
-        
-        newcoord = type(lastcoord)(np.arange(size)*deltaf + first)
+
+        newcoord = type(lastcoord)(np.arange(size) * deltaf + first)
         newcoord.name = lastcoord.name
         newcoord.title = 'frequency'
         newcoord.ito("Hz")
-        
+
     else:
         # frequency or ppm to time
-        sw = abs(lastcoord.data[-1]-lastcoord.data[0])
+        sw = abs(lastcoord.data[-1] - lastcoord.data[0])
         if lastcoord.units == 'ppm':
             sw = bf1.to("Hz") * sw / 1.0e6
-        deltat = 1. /sw
-        
-        newcoord = type(lastcoord)(np.arange(size)*deltat)
+        deltat = 1. / sw
+
+        newcoord = type(lastcoord)(np.arange(size) * deltat)
         newcoord.name = lastcoord.name
         newcoord.title = 'time'
         newcoord.ito("s")
-        
+
     if is_nmr and not inv:
         newcoord.meta.larmor = bf1  # needed for ppm transformation
         newcoord.origin = 'bruker'
@@ -221,34 +223,35 @@ def fft(dataset, size=None, sizeff=None, inv=False, inplace=False, dim=-1, ppm=T
             else:
                 nucleus = ""
             newcoord.title = fr"$\delta\ {nucleus}$"
-    
-    new.coords[-1]=newcoord
+
+    new.coords[-1] = newcoord
 
     # if some phase related metadata do not exist yet, initialize them
     new.meta.readonly = False
-    
+
     if not new.meta.phased:
         new.meta.phased = [False] * new.ndim
-        
+
     if not new.meta.pivot:
-        new.meta.pivot = [float(abs(new).max().coords[i].data) * new.coords[i].units for i in range(new.ndim) ]  # create pivot metadata
-        
+        new.meta.pivot = [float(abs(new).max().coords[i].data) * new.coords[i].units for i in
+                          range(new.ndim)]  # create pivot metadata
+
     # applied the stored phases
     new.pk(inplace=True)
-    
+
     new.meta.phased[-1] = True
-    
+
     new.meta.readonly = True
 
     # restore original data order if it was swaped
     if swaped:
         new.swapaxes(axis, -1, inplace=True)  # must be done inplace
-        
+
     new.history = f'fft applied on dimension {dim}'
-    
+
     return new
 
 
 # ======================================================================================================================
 if __name__ == '__main__':  # pragma: no cover
-    pass
\ No newline at end of file
+    pass
