@@ -26,18 +26,17 @@ import os
 # Third party imports
 # ======================================================================================================================
 import numpy as np
-from ....extern.nmrglue.fileio.bruker import read, read_pdata, read_lowmem
+from nmrglue.fileio.bruker import read, read_pdata, read_lowmem
 
 # ======================================================================================================================
 # Local imports
 # ======================================================================================================================
-from ....core import project_preferences, general_preferences as prefs
-from ....core import info_, debug_, error_, warning_
+from spectrochempy.core import general_preferences as prefs, info_, warning_
 
-from ....utils.meta import Meta
-from ....core.dataset.nddataset import NDDataset
-from ....core.dataset.ndcoord import Coord
-from ....units import ur, Quantity
+from spectrochempy.utils.meta import Meta
+from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.core.dataset.ndcoord import Coord
+from spectrochempy.units import ur, Quantity
 from .parameter import nmr_valid_meta
 
 # ======================================================================================================================
@@ -182,6 +181,7 @@ bruker_dsp_table = {
     }
 }
 
+
 def _remove_digital_filter(dic, data):
     """
     Remove the digital filter from Bruker data.
@@ -242,7 +242,7 @@ def _remove_digital_filter(dic, data):
     dic['acqus']['TD'] = td * 2
     data = data[..., :td]
 
-    #debug_('Bruker digital filter : removed %s points' % rp)
+    # debug_('Bruker digital filter : removed %s points' % rp)
 
     return data
 
@@ -371,7 +371,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
 
     lowmem = kwargs.get('lowmem', False)  # load all in memero by default
     if lowmem:
-        #debug_('import with low memory handling (lowmem)')
+        # debug_('import with low memory handling (lowmem)')
         pass
     # ------------------------------------------------------------------------------------------------------------------
     # start reading ....
@@ -421,7 +421,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
         else:
             if not processed:
                 warning_('No binary fid or ser found in %s.\n'
-                            'Try processed files...' % path)
+                         'Try processed files...' % path)
                 processed = True
 
         if os.path.isfile(os.path.join(path, 'pdata', procno, '1r')):
@@ -449,8 +449,8 @@ def read_bruker_nmr(dataset, *args, **kwargs):
             else:
                 dic, data = read_lowmem(npath, acqus_files=par_files, read_pulseprogram=False)
 
-            data = data * np.exp(- 1j * np.pi/2.) # -90 phase to be compatible with topspin
-            
+            data = data * np.exp(- 1j * np.pi / 2.)  # -90 phase to be compatible with topspin
+
             # look the case when the reshaping was not correct
             # for example, this happen when the number
             # of accumulated row was incomplete
@@ -472,7 +472,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
                 # necessary for agreement with bruker data and phase
         else:
 
-            #debug_(f'Reading processed {idx}:{path}')
+            # debug_(f'Reading processed {idx}:{path}')
 
             dic, data = read_pdata(npath, procs_files=par_files, )
 
@@ -526,7 +526,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
                     if units is not None:
                         if isinstance(value, (float, int)):
                             value = value * units  # make a quantity
-                        elif isinstance(value, list) and isinstance(value[0],(float,int)):
+                        elif isinstance(value, list) and isinstance(value[0], (float, int)):
                             value = np.array(value) * units
 
                     if not item.endswith('s'):  # initial parameter
@@ -539,7 +539,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
                     else:  # status parameters (replace initial)
                         try:
                             meta[key.lower()][dim] = value
-                        except:
+                        except Exception:
                             pass
 
             else:
@@ -618,7 +618,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
         list_meta.append(meta)
 
         # make the corresponding axis
-        #debug_('Create coords...')
+        # debug_('Create coords...')
         coords = []
         axe_range = list(range(parmode + 1))
         for axis in axe_range:
@@ -627,7 +627,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
                 dw = (1. / meta.sw_h[axis]).to('us')
                 coordpoints = np.arange(meta.td[axis])
                 coord = Coord(coordpoints * dw,
-                              title=f"F{axis+1} acquisition time")    #TODO: use AQSEQ for >2D data
+                              title=f"F{axis + 1} acquisition time")  # TODO: use AQSEQ for >2D data
                 coords.append(coord)
             else:
                 raise NotImplementedError('Not yet implemented')
@@ -653,12 +653,12 @@ def read_bruker_nmr(dataset, *args, **kwargs):
         #     ldates.append(adic.par.DATE)  # and the date
 
         # store temporarily these data
-        #debug_('data read finished : type : %s' % datatype)
+        # debug_('data read finished : type : %s' % datatype)
 
         list_data.append(data)
 
     if len(list_data) == 1:
-        #debug_('One experiment read. Make it the current dataset')
+        # debug_('One experiment read. Make it the current dataset')
 
         dataset.data = list_data[0]
 
@@ -668,12 +668,12 @@ def read_bruker_nmr(dataset, *args, **kwargs):
 
         dataset.meta.update(list_meta[0])
         dataset.meta.readonly = True
-        dataset.set_coords(*tuple(list_coords[0]))    # must be a tuple
+        dataset.set_coords(*tuple(list_coords[0]))  # must be a tuple
         dataset.title = 'intensity'
         dataset.origin = 'bruker'
-        
+
     else:
-        
+
         # TODO: Check this -
         # case of multiple experiments to merge
 
@@ -694,7 +694,7 @@ def read_bruker_nmr(dataset, *args, **kwargs):
 
         if not diff:
             info_('the experiments look perfectly compatibles'
-                     ' regarding the shape and the axis!')
+                  ' regarding the shape and the axis!')
 
         # find what are the differences in meta
         meta = list_meta[0]
@@ -781,5 +781,3 @@ def read_bruker_nmr(dataset, *args, **kwargs):
             dataset.origin = 'bruker'
 
     return dataset
-
-###EOF######################################################################
