@@ -27,7 +27,7 @@ from spectrochempy.core import debug_
 from spectrochempy.core.dataset.ndcoord import Coord
 from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.core.dataset.ndio import NDIO
-from spectrochempy.utils import readfilename
+from spectrochempy.utils import readfilename, pathclean
 
 
 # ----------------------------------------------------------------------------------------------------------------------
@@ -44,7 +44,16 @@ from spectrochempy.utils import readfilename
 # .............................................................................
 def read_omnic(dataset=None, **kwargs):
     """Open a Thermo Nicolet with extension ``.spg`` or a list of ``.spa`` files
-     and set data/metadata in the current dataset
+     and set data/metadata in the current dataset. The collected metatdata are:
+     - names of spectra
+     - acquisition dates (UTC)
+     - units of spectra (absorbance, transmittance, reflectance, Log(1/R), Kubelka-Munk,
+     Raman intensity, photoacoustics, volts)
+     - units of xaxis (wavenumbers in cm-1, wavelengths in nm or micrometer, Raman shift in cm-1)
+     - spectra history (but only incorporated in the NDDataset if single spa is read)
+
+     An error is generated if attempt is made to inconsistent datasets: units of spectra and
+     xaxis, limits and number of points of the xaxis.
 
     Parameters
     ----------
@@ -57,6 +66,8 @@ def read_omnic(dataset=None, **kwargs):
         the defaults datadir.
     sortbydate : bool, optional, default=True.
         Sort spectra by acquisition date
+    description: string, default=None
+        Custom description
 
     Returns
     -------
@@ -76,7 +87,7 @@ def read_omnic(dataset=None, **kwargs):
     debug_("reading omnic files")
 
     # filename will be given by a keyword parameter except if the first parameters is already the filename
-    filename = kwargs.get('filename', None)
+    filename = pathclean(kwargs.get('filename', None))
 
     # check if the first parameter is a dataset because we allow not to pass it
     if not isinstance(dataset, NDDataset):
@@ -87,14 +98,14 @@ def read_omnic(dataset=None, **kwargs):
 
         dataset = NDDataset()  # create an instance of NDDataset
 
-    # check if directory was specified
-    directory = kwargs.get("directory", None)
-    sortbydate = kwargs.get("sortbydate", True)
+    sortbydate = kwargs.pop("sortbydate", True)
 
     # returns a list of files to read
+    directory = pathclean(kwargs.get("directory", None))
     files = readfilename(filename,
                          directory=directory,
                          filetypes=['OMNIC files (*.spa, *.spg)',
+                                    'OMNIC series (*.srs)',
                                     'all files (*)'])
 
     if not files:
@@ -108,12 +119,14 @@ def read_omnic(dataset=None, **kwargs):
 
         if extension == '.spg':
             for filename in files[extension]:
-                # debug_("reading omnic spg file")
-                datasets.append(_read_spg(dataset, filename, sortbydate=sortbydate))
+                datasets.append(_read_spg(dataset, filename, **kwargs))
 
         elif extension == '.spa':
-            # debug_("reading omnic spa files")
-            datasets.append(_read_spa(dataset, files[extension], sortbydate=sortbydate))
+            datasets.append(_read_spa(dataset, files[extension], **kwargs))
+
+        elif extension == '.srs':
+            for filename in files[extension]:
+                datasets.append(_read_srs(dataset, filename, **kwargs))
         else:
             # try another format!
             datasets = dataset.read(filename, protocol=extension[1:], sortbydate=sortbydate, **kwargs)
@@ -138,7 +151,7 @@ NDIO.read_spa = read_omnic
 # private functions
 # ======================================================================================================================
 
-# .............................................................................
+
 def _readbtext(f, pos):
     # Read some text in binary file, until b\0\ is encountered.
     # Returns utf-8 string
@@ -159,7 +172,109 @@ def _readbtext(f, pos):
     return text
 
 
+def _readheader02(f, pos):
+    # read spectrum header, pos is the position of the 02 key
+    # returns a dict
+    f.seek(pos + 2)  # go to line and skip 2 bytes
+    info_pos = np.fromfile(f, dtype='uint32', count=1)[0]
+
+    # other positions:
+    #   nx_pos = info_pos + 4
+    #   xaxis unit code = info_pos + 8
+    #   data unit code = info_pos + 12
+    #   fistx_pos = info_pos + 16
+    #   lastx_pos = info_pos + 20
+    #   nscan_pos = info_pos + 36;
+    #   nbkgscan_pos = info_pos + 52;
+
+    f.seek(info_pos + 4)
+    out = {'nx': np.fromfile(f, 'uint32', 1)}
+
+    # read xaxis unit
+    f.seek(info_pos + 8)
+    key = np.fromfile(f, dtype='uint8', count=1)[0]
+    if key == 1:
+        out['xunits'] = 'cm ^ -1'
+        out['xtitle'] = 'Wavenumbers'
+    elif key == 2:
+        out['xunits'] = None
+        out['xtitle'] = 'Data points'
+    elif key == 3:
+        out['xunits'] = 'nm'
+        out['xtitle'] = 'Wavelengths'
+    elif key == 4:
+        out['xunits'] = 'um'
+        out['xtitle'] = 'Wavelengths'
+    elif key == 32:
+        out['xunits'] = 'cm^-1'
+        out['xtitle'] = 'Raman Shift'
+    else:
+        out['xunits'] = None
+        out['xtitle'] = 'xaxis'
+        # warning: 'The nature of data is not recognized, xtitle set to \'xaxis\')
+
+    # read data unit
+    f.seek(info_pos + 12)
+    key = np.fromfile(f, dtype='uint8', count=1)[0]
+    if key == 17:
+        out['units'] = 'absorbance'
+        out['title'] = 'Absorbance'
+    elif key == 16:
+        out['units'] = 'percent'
+        out['title'] = 'Transmittance'
+    elif key == 11:
+        out['units'] = 'percent'
+        out['title'] = 'Reflectance'
+    elif key == 12:
+        out['units'] = None
+        out['title'] = 'Log(1/R)'
+    elif key == 20:
+        out['units'] = 'Kubelka_Munk'
+        out['title'] = 'Kubelka-Munk'
+    elif key == 22:
+        out['units'] = 'V'
+        out['title'] = 'Volts'
+    elif key == 26:
+        out['units'] = None
+        out['title'] = 'Photoacoustic'
+    elif key == 31:
+        out['units'] = None
+        out['title'] = 'Raman Intensity'
+    else:
+        out['title'] = None
+        out['title'] = 'Intensity'
+        # warning: 'The nature of data is not recognized, title set to \'Intensity\')
+
+    f.seek(info_pos + 16)
+    out['firstx'] = np.fromfile(f, 'float32', 1)
+    f.seek(info_pos + 20)
+    out['lastx'] = np.fromfile(f, 'float32', 1)
+    f.seek(info_pos + 36)
+    out['nscan'] = np.fromfile(f, 'uint32', 1)
+    f.seek(info_pos + 52)
+    out['nbkgscan'] = np.fromfile(f, 'uint32', 1)
+
+    return out
+
+
+def _getintensities(f, pos):
+    # get intensities from the 03 key
+    # returns a ndarray
+
+    f.seek(pos + 2)  # skip 2 bytes
+    intensity_pos = np.fromfile(f, 'uint32', 1)[0]
+    f.seek(pos + 6)
+    intensity_size = np.fromfile(f, 'uint32', 1)[0]
+    nintensities = int(intensity_size / 4)
+
+    # Read and return spectral intensities
+    f.seek(intensity_pos)
+    return np.fromfile(f, 'float32', int(nintensities))
+
+
 # .............................................................................
+
+
 def _read_spg(dataset, filename, **kwargs):
     # read spg file
 
@@ -167,19 +282,12 @@ def _read_spg(dataset, filename, **kwargs):
     with open(filename, 'rb') as f:
 
         # Read title:
-        # The file title starts at position hex 1e = decimal 30.
-        # Its max length is 256 bytes and it is followed by at least
-        # one \0. It is the original filename under which the group has
-        # been saved: it won't match with the actual filename if a subsequent
-        # renaming has been done in e.g. Windows.
+        # The file title starts at position hex 1e = decimal 30. Its max length is 256 bytes.
+        #  It is the original filename under which the group has been saved: it won't match with
+        #  the actual filename if a subsequent renaming has been done in the OS.
 
         spg_title = _readbtext(f, 30)
 
-        # The acquisition date (GMT) of 1st spectrum at hex 128 = decimal 296.
-        # The format is HFS+ 32 bit hex value, little endian
-
-        f.seek(296)
-
         # Count the number of spectra
         # From hex 120 = decimal 304, individual spectra are described
         # by blocks of lines starting with "key values",
@@ -200,9 +308,7 @@ def _read_spg(dataset, filename, **kwargs):
         #
         # the number of line per block may change from one omnic version to another,
         # but the total number of lines is given at hex 294, hence allowing counting
-        # nummber of spectra:
-
-        # np.nonzero((code == 2)) ; np.count_nonzero((a==2))
+        # number of spectra:
 
         # read total number of lines
         f.seek(294)
@@ -216,97 +322,67 @@ def _read_spg(dataset, filename, **kwargs):
             keys[i] = np.fromfile(f, dtype='uint8', count=1)[0]
             pos = pos + 16
 
-        # count the number of occurences of the key '02' == number of spectra
+        # the number of occurences of the key '02' is number of spectra
         nspec = np.count_nonzero((keys == 2))
 
         if nspec == 0:
             raise IOError('Error : File format not recognized'
                           ' - information markers not found')
 
-        # Get xaxis (e.g. wavenumbers)
         # container to hold values
         nx, firstx, lastx = np.zeros(nspec, 'int'), np.zeros(nspec, 'float'), np.zeros(nspec, 'float')
+        xunits = []
+        xtitles = []
+        units = []
+        titles = []
 
         # Extracts positions of '02' keys
         key_is_02 = (keys == 2)  # ex: [T F F F F T F (...) F T ....]'
         indices02 = np.nonzero(key_is_02)  # ex: [1 9 ...]
-        position02 = 304 * np.ones(len(indices02[0]), dtype='int') + 16 * indices02[0]
+        position02 = 304 * np.ones(len(indices02[0]), dtype='int') + 16 * indices02[0]  # ex: [304 432 ...]
 
-        # ex: [304 432 ...]
         for i in range(nspec):
-            f.seek(position02[i] + 2)  # go to line and skip 2 bytes
-            info_pos = np.fromfile(f, dtype='uint32', count=1)[0]
-            nx_pos = info_pos + 4
-            firstx_pos = info_pos + 16
-            lastx_pos = info_pos + 20
-            # other positions of potential interest:
-            #   nscan_pos = info_pos + 36;
-            #   nbkgscan_pos = info_pos + 52;
+            info02 = _readheader02(f, position02[i])
+            nx[i] = info02['nx']
+            firstx[i] = info02['firstx']
+            lastx[i] = info02['lastx']
+            xunits.append(info02['xunits'])
+            xtitles.append(info02['xtitle'])
+            units.append(info02['units'])
+            titles.append(info02['title'])
 
-            f.seek(nx_pos)
-            nx[i] = np.fromfile(f, 'uint32', 1)
-            f.seek(firstx_pos)
-            firstx[i] = np.fromfile(f, 'float32', 1)
-            f.seek(lastx_pos)
-            lastx[i] = np.fromfile(f, 'float32', 1)
-
-        # check the consistency of xaxis
+        # check the consistency of xaxis and data units
         if np.ptp(nx) != 0:
-            raise ValueError('Inconsistant data set'
-                             ' - number of wavenumber per spectrum should be identical')
-
+            raise ValueError('Error : Inconsistent data set -'
+                             ' number of wavenumber per spectrum should be identical')
         elif np.ptp(firstx) != 0:
-            raise ValueError('Inconsistant data set'
-                             ' - the x axis should start at same value')
-
+            raise ValueError('Error : Inconsistent data set - '
+                             'the x axis should start at same value')
         elif np.ptp(lastx) != 0:
-            raise ValueError('Inconsistant data set'
-                             ' - the x axis should end at same value')
-
-        xaxis = np.around(np.linspace(firstx[0], lastx[0], nx[0]), 3)
+            raise ValueError('Error : Inconsistent data set -'
+                             ' the x axis should end at same value')
+        elif len(set(xunits)) != 1:
+            raise ValueError('Error : Inconsistent data set - '
+                             'data units should be identical')
+        elif len(set(units)) != 1:
+            raise ValueError('Error : Inconsistent data set - '
+                             'x axis units should be identical')
 
+        data = np.ndarray((nspec, nx[0]), dtype='float32')
         # now the intensity data
-
-        # container to hold values
-        intensity_pos, intensity_size = np.zeros(nspec, 'int'), np.zeros(nspec, 'int')
-
-        # Extracts positions of '02' keys
+        # Extracts positions of '03' keys
         key_is_03 = (keys == 3)
         indices03 = np.nonzero(key_is_03)
         position03 = 304 * np.ones(len(indices03[0]), dtype='int') + 16 * indices03[0]
 
         # Read number of spectral intensities
         for i in range(nspec):
-            # determines the position of informatioon
-            f.seek(position03[i] + 2)  # go to line and skip 2 bytes
-            intensity_pos[i] = np.fromfile(f, 'uint32', 1)
-            f.seek(position03[i] + 6)
-            intensity_size[i] = np.fromfile(f, 'uint32', 1)
-
-        # check the consistency of intensities
-        # (probably redundent w/ xaxis check above)
-        if np.ptp(intensity_size) != 0:
-            raise ValueError('Inconsistent data set'
-                             ' - number of data per spectrum should be identical')
-
-        nintensities = int(intensity_size[0] / 4)  # 4 = size of uint32
-
-        if nintensities != nx[0]:
-            raise ValueError('Inconsistent file'
-                             ' - number of wavenumber per spectrum should be equal to number of intensities')
-
-        # Read spectral intensities
-        # ..............................................................................................................
-        data = np.zeros((nspec, nintensities), dtype='float32')
-        for i in range(nspec):
-            f.seek(intensity_pos[i])
-            data[i, :] = np.fromfile(f, 'float32', int(nintensities))
+            data[i, :] = _getintensities(f, position03[i])
         # ..............................................................................................................
 
-        # Get spectra titles & acquisition dates & history text
+        # Get spectra titles & acquisition dates:
         # container to hold values
-        alltitles, allacquisitiondates = [], []
-        alltimestamps, allhistories = [], []
+        spectitles, acquisitiondates, timestamps = [], [], []
 
         # extract positions of '6B' keys (spectra titles & acquisition dates)
         key_is_6B = (keys == 107)
@@ -321,64 +397,66 @@ def _read_spg(dataset, filename, **kwargs):
 
             # read filename
             spa_title = _readbtext(f, spa_title_pos[0])
-            alltitles.append(spa_title)
+            spectitles.append(spa_title)
 
             # and the acquisition date
             f.seek(spa_title_pos[0] + 256)
-            timestamp = np.fromfile(f, dtype=np.uint32, count=1)[
-                0]  # days since 31/12/1899, 00:00
+            timestamp = np.fromfile(f, dtype=np.uint32, count=1)[0]  # days since 31/12/1899, 00:00
             acqdate = datetime(1899, 12, 31, 0, 0, tzinfo=timezone.utc) + timedelta(seconds=int(timestamp))
-            allacquisitiondates.append(acqdate)
+            acquisitiondates.append(acqdate)
             timestamp = acqdate.timestamp()
             # Transform back to timestamp for storage in the Coord object
             # use datetime.fromtimestamp(d, timezone.utc))
             # to transform back to datetime obkct
 
-            alltimestamps.append(timestamp)
+            timestamps.append(timestamp)
 
+            # Not used at present
+            # -------------------
             # extract positions of '1B' codes (history text
             #  -- sometimes absent, e.g. peakresolve)
-            key_is_1B = (keys == 27)
-            indices1B = np.nonzero(key_is_1B)
-            position1B = 304 * np.ones(len(indices1B[0]), dtype='int') + 16 * indices6B[0]
-
-            if len(position1B) != 0:
-                # read history texts
-                for j in range(nspec):
-                    # determine the position of information
-                    f.seek(position1B[j] + 2)
-                    history_pos = np.fromfile(f, 'uint32', 1)
-
-                    # read history
-                    history = _readbtext(f, history_pos[0])
-                    allhistories.append(history)
+            # key_is_1B = (keys == 27)
+            # indices1B = np.nonzero(key_is_1B)
+            # position1B = 304 * np.ones(len(indices1B[0]), dtype='int') + 16 * indices6B[0]
+            # if len(position1B) != 0:
+            #    # read history texts
+            #    for j in range(nspec):
+            #        # determine the position of information
+            #        f.seek(position1B[j] + 2)
+            #        history_pos = np.fromfile(f, 'uint32', 1)
+            #        # read history
+            #        history = _readbtext(f, history_pos[0])
+            #        allhistories.append(history)
 
     # Create Dataset Object of spectral content
     dataset.data = data
-    dataset.units = 'absorbance'
-    dataset.title = 'Absorbance'
+    dataset.units = units[0]
+    dataset.title = titles[0]
     dataset.name = spg_title
     dataset.filename = os.path.basename(filename).split('.')[0]
 
     # now add coordinates
-    _x = Coord(xaxis, title='Wavenumbers', units='cm^-1')
-    _y = Coord(alltimestamps,
+    _x = Coord(np.around(np.linspace(firstx[0], lastx[0], nx[0]), 3),
+               title=xtitles[0],
+               units=xunits[0])
+
+    _y = Coord(timestamps,
                title='Acquisition timestamp (GMT)',
                units='s',
-               labels=(allacquisitiondates, alltitles))
+               labels=(acquisitiondates, spectitles))
+
     dataset.set_coords(y=_y, x=_x)
 
     # Set origin, description and history
     dataset.origin = "omnic"
-    dataset.description = (
-            'Dataset from spg file : ' + spg_title + ' \n'
-            + 'History of the 1st spectrum : ' + allhistories[0])
+    dataset.description = kwargs.get('description',
+                                     'Dataset from spg file {} : '.format(filename))
 
-    dataset.history = str(datetime.now()) + ':read from spg file \n'
+    dataset.history = str(datetime.now()) + ':imported from spg file {} ; '.format(filename)
 
     if sortbydate:
         dataset.sort(dim='y', inplace=True)
-        dataset.history = 'Sorted'
+        dataset.history = str(datetime.now()) + ':sorted by date'
 
     # Set the NDDataset date
     dataset._date = datetime.now()
@@ -389,7 +467,6 @@ def _read_spg(dataset, filename, **kwargs):
     return dataset
 
 
-# .............................................................................
 def _read_spa(dataset, filenames, **kwargs):
     nspec = len(filenames)
 
@@ -398,7 +475,11 @@ def _read_spa(dataset, filenames, **kwargs):
     firstx = np.zeros(nspec, 'float')
     lastx = np.zeros(nspec, 'float')
     allintensities = []
-    alltitles = []
+    xunits = []
+    xtitles = []
+    units = []
+    titles = []
+    spectitles = []
     allacquisitiondates = []
     alltimestamps = []
     allhistories = []
@@ -408,13 +489,11 @@ def _read_spa(dataset, filenames, **kwargs):
         with open(_filename, 'rb') as f:
 
             # Read title:
-            # The file title  starts at position hex 1e = decimal 30.
-            # Its max length is 256 bytes and it is followed by at least
-            # one \0. It is the original filename under which the group has
-            # been saved: it won't match with the actual filename if a subsequent
-            # renaming has been done in e.g. Windows.
+            # The file title  starts at position hex 1e = decimal 30. Its max length is 256 bytes. It is the original
+            # filename under which the group has  been saved: it won't match with the actual filename if a subsequent
+            # renaming has been done in the OS.
 
-            alltitles.append(_readbtext(f, 30))
+            spectitles.append(_readbtext(f, 30))
 
             # The acquisition date (GMT) is at hex 128 = decimal 296.
             # The format is HFS+ 32 bit hex value, little endian
@@ -423,8 +502,7 @@ def _read_spa(dataset, filenames, **kwargs):
 
             # days since 31/12/1899, 00:00
             timestamp = np.fromfile(f, dtype=np.uint32, count=1)[0]
-            acqdate = datetime(1899, 12, 31, 0, 0, tzinfo=timezone.utc) + \
-                      timedelta(seconds=int(timestamp))
+            acqdate = datetime(1899, 12, 31, 0, 0, tzinfo=timezone.utc) + timedelta(seconds=int(timestamp))
             allacquisitiondates.append(acqdate)
             timestamp = acqdate.timestamp()
             # Transform back to timestamp for storage in the Coord object
@@ -447,53 +525,26 @@ def _read_spa(dataset, filenames, **kwargs):
             #     key: hex 6a, dec 106: ?
             #     key: hex 80, dec 128: ?
             #     key: hex 82, dec 130: ?
-            #
 
-            gotinfos = [False, False,
-                        False]  # spectral header, intensity, history
+            gotinfos = [False, False, False]  # spectral header, intensity, history
             # scan "key values"
             pos = 304
-            #        keys = np.zeros((nlines))
-            #        for i in range(nlines):
-            #            f.seek(pos)
-            #            keys[i] = np.fromfile(f, dtype = 'uint8', count = 1)[0]
-            #        pos = pos + 16
-
             while not (all(gotinfos)):
                 f.seek(pos)
                 key = np.fromfile(f, dtype='uint8', count=1)[0]
                 if key == 2:
-                    f.seek(pos + 2)  # skip 2 bytes
-                    info_pos = np.fromfile(f, dtype='uint32', count=1)[0]
-                    nx_pos = info_pos + 4
-                    firstx_pos = info_pos + 16
-                    lastx_pos = info_pos + 20
-                    # other positions of potential interest:
-                    #   nscan_pos = info_pos + 36;
-                    #   nbkgscan_pos = info_pos + 52;
-
-                    f.seek(nx_pos)
-                    nx[i] = np.fromfile(f, 'uint32', 1)[0]
-                    f.seek(firstx_pos)
-                    firstx[i] = np.fromfile(f, 'float32', 1)[0]
-                    f.seek(lastx_pos)
-                    lastx[i] = np.fromfile(f, 'float32', 1)[0]
-
-                    xaxis = np.around(
-                        np.linspace(firstx[0], lastx[0], nx[0]), 3)
+                    info02 = _readheader02(f, pos)
+                    nx[i] = info02['nx']
+                    firstx[i] = info02['firstx']
+                    lastx[i] = info02['lastx']
+                    xunits.append(info02['xunits'])
+                    xtitles.append(info02['xtitle'])
+                    units.append(info02['units'])
+                    titles.append(info02['title'])
                     gotinfos[0] = True
 
                 elif key == 3:
-                    f.seek(pos + 2)  # skip 2 bytes
-                    intensity_pos = np.fromfile(f, 'uint32', 1)[0]
-                    f.seek(pos + 6)
-                    intensity_size = np.fromfile(f, 'uint32', 1)[0]
-
-                    nintensities = int(intensity_size / 4)
-                    # Read spectral intensities
-                    f.seek(intensity_pos)
-                    allintensities.append(
-                        np.fromfile(f, 'float32', int(nintensities)))
+                    allintensities.append(_getintensities(f, pos))
                     gotinfos[1] = True
 
                 elif key == 27:
@@ -507,9 +558,9 @@ def _read_spa(dataset, filenames, **kwargs):
                 elif not key:
                     break
 
-                pos = pos + 16
+                pos += 16
 
-    # check the consistency of xaxis
+    # check the consistency of xaxis and data units
     if np.ptp(nx) != 0:
         raise ValueError(
             'Error : Inconsistent data set - number of wavenumber per spectrum should be identical')
@@ -519,38 +570,48 @@ def _read_spa(dataset, filenames, **kwargs):
     elif np.ptp(lastx) != 0:
         raise ValueError(
             'Error : Inconsistent data set - the x axis should end at same value')
+    elif len(set(xunits)) != 1:
+        raise ValueError(
+            'Error : Inconsistent data set - data units should be identical')
+    elif len(set(units)) != 1:
+        raise ValueError(
+            'Error : Inconsistent data set - x axis units should be identical')
 
-    # load into the  NDDataset Object of spectral content
-    dataset.data = np.array(allintensities)
-    dataset.units = 'absorbance'
-    dataset.title = 'Absorbance'
-    dataset.name = ' ... '.join({alltitles[0], alltitles[-1]})
+    # load spectral content into the  NDDataset
+    dataset.data = np.array(allintensities, dtype='float32')
+    dataset.units = units[0]
+    dataset.title = titles[0]
+    dataset.name = ' ... '.join({spectitles[0], spectitles[-1]})
     dataset._date = dataset._modified = datetime.now()
 
-    # Create Dataset Object of spectral content
     # now add coordinates
-    _x = Coord(xaxis, title='Wavenumbers', units='cm^-1')
-    _y = Coord(alltimestamps, title='Acquisition timestamp (GMT)', units='s', labels=(allacquisitiondates, alltitles))
+    _x = Coord(np.around(np.linspace(firstx[0], lastx[0], nx[0]), 3),
+               title=xtitles[0],
+               units=xunits[0])
+
+    _y = Coord(alltimestamps, title='Acquisition timestamp (GMT)', units='s', labels=(allacquisitiondates, titles))
     dataset.set_coords(y=_y, x=_x)
 
-    # Set origin, description and history
+    # Set origin, description, history, date
     dataset.origin = "omnic"
-    dataset.description = "Dataset from {0} spa files : '{1}'\nHistory of the {2}spectrum : {3}".format(
-        nspec, ' ... '.join({filenames[0], filenames[-1]}), '1st ' if nspec > 1 else '', allhistories[0])
+    dataset.description = kwargs.get('description',
+                                     "Dataset from {0} spa files : {1}".format(
+                                         nspec, ' ... '.join({filenames[0], filenames[-1]}))
+                                     )
 
-    dataset.history = str(datetime.now()) + ':read from spa files \n'
+    dataset.history = str(datetime.now()) + ':read from spa files ; '
 
-    if kwargs.get('sortbydate', True):
+    if kwargs.get('sortbydate', True) and nspec > 1:
         dataset.sort(dim=0, inplace=True)
         dataset.history = 'Sorted'
 
-    # Set the NDDataset date
     dataset._date = datetime.now()
     dataset._modified = dataset.date
 
-    # debug_("end of reading")
+    return dataset
 
-    # return the dataset
+
+def _read_srs(dataset, filenames, **kwargs):
     return dataset
 
 
