@@ -11,5 +11,5 @@
 Package to handle units (interface with `pint`.
 """
 
-from .units import *
-from .units import __all__
+from .units import *           # noqa: F403, F401, E402
+from .units import __all__     # noqa: F401
