@@ -8,14 +8,14 @@
 # ======================================================================================================================
 
 import warnings
-from .print import pstr
+# from .print import pstr
 
 __all__ = ['SpectroChemPyWarning',
            'SpectroChemPyDeprecationWarning',
            'SpectroChemPyException',
            'UnitsCompatibilityError',
            'deprecated',
-          ]
+           ]
 
 
 # ======================================================================================================================
@@ -26,7 +26,7 @@ __all__ = ['SpectroChemPyWarning',
 class SpectroChemPyWarning(Warning):
     """
     The base warning class for SpectroChemPy warnings.
-    
+
     """
 
 
@@ -34,7 +34,7 @@ class SpectroChemPyWarning(Warning):
 class SpectroChemPyDeprecationWarning(SpectroChemPyWarning):
     """
     A warning class to indicate that something is deprecated.
-    
+
     """
 
 
@@ -42,16 +42,16 @@ class SpectroChemPyDeprecationWarning(SpectroChemPyWarning):
 class SpectroChemPyException(Exception):
     """
     The base exception class for SpectroChemPy
-    
+
     """
 
+
 # ----------------------------------------------------------------------------------------------------------------------
 class UnitsCompatibilityError(SpectroChemPyException):
     """
     Exception raised when units are not compatible, preventing some mathematical operations
-    
+
     """
-    
 
 
 # ----------------------------------------------------------------------------------------------------------------------
