@@ -11,6 +11,8 @@ import os
 import sys
 import io
 import json
+import warnings
+from pathlib import Path, WindowsPath
 from pkgutil import walk_packages
 from numpy.lib.format import read_array
 from numpy.compat import asstr
@@ -18,7 +20,7 @@ from traitlets import import_item
 
 from .qtfiledialogs import opendialog, SaveFileName
 
-__all__ = ['readfilename', 'readdirname', 'savefilename',
+__all__ = ['readfilename', 'readdirname', 'savefilename', 'pathclean',
            'list_packages', 'generate_api',
            'make_zipfile', 'ScpFile',
            'unzip'  # tempo
@@ -26,8 +28,40 @@ __all__ = ['readfilename', 'readdirname', 'savefilename',
 
 
 # ======================================================================================================================
-# Utility function
+# Utility functions
 # ======================================================================================================================
+def pathclean(path):
+    """
+    Clean the path in order to be compatible with windows and unix-based system.
+
+    Parameters
+    ----------
+    path :  str
+        Path to clean. It may contain windows or conventional python separators.
+        If a windows drive letters is specified, the letter is suppressed when run on unix-based system
+
+    Returns
+    -------
+    out : str
+        Cleaned path
+
+    """
+    if path is not None:
+        try:
+            path = WindowsPath(path)
+            path = path.as_posix()
+        except NotImplementedError:
+            # we are not on window.
+            path = Path(path)
+            path = path.as_posix()
+            if ':' in path:
+                # looks like a window path (but we are not on windows)
+                # let's try without the drive
+                i = path.index(':')
+                path = path[i+1:]
+    return path
+
+
 
 def readfilename(filename=None, **kwargs):
     """
@@ -35,22 +69,20 @@ def readfilename(filename=None, **kwargs):
 
     Parameters
     ----------
-    filename : `str`, `list` of strings, optional.
+    filename : `str` or `list` of strings, optional.
         A filename or a list of filenames. If not provided, a dialog box is opened
-        to select files in the specified directory or in
-        the current directory if not specified.
+        to select files in the specified directory or in the current directory if not specified.
     directory : `str`, optional.
         The directory where to look at. If not specified, read in
         current directory, or in the datadir if unsuccessful
-
-    filetypes : `list`, optional filter, default=['all files, '.*)'].
-
-    dictionary: `bool`, default=True
+    filetypes : `list`, optional, default=['all files, '.*)'].
+        file type filter
+    dictionary : `bool`, optional, default=True
         Whether a dictionary or a list should be returns
 
     Returns
     --------
-        list of filenames
+    out : list of filenames
 
     """
 
@@ -66,28 +98,16 @@ def readfilename(filename=None, **kwargs):
 
     # check passed directory
     if directory:
-        if os.path.exists(directory):
-            # a valid absolute pathname has been given
-            pass
-        else:
-            # if the directory is not specified we will first look in the current working directory
-            # and then in the prefs.datadir
-            _directory = os.path.join(os.getcwd(), directory)
-            if not os.path.exists(_directory):
-                # the directory isn't in the current dir, now try datadir:
-                _directory = os.path.join(prefs.datadir, directory)
-                if not os.path.exists(_directory):
-                    # the directory is definitely not valid... raise an error
-                    raise IOError("directory %s doesn't exists!" % directory)
-            else:
-                directory = _directory
+        directory = readdirname(directory)
 
     # now proceed with the filenames
-    
     if not filename:
         # test if we are running nbsphinx with this default filename
         filename = os.environ.get('TUTORIAL_FILENAME', None)
-        
+
+        if not filename and "--nodisplay" in sys.argv:
+            return None  # or we can set a filename here
+
     if filename:
         _filenames = []
         # make a list, even for a single file name
@@ -110,13 +130,13 @@ def readfilename(filename=None, **kwargs):
                     _f = os.path.join(prefs.datadir, filename)
                     if not os.path.exists(_f):
                         raise IOError("Can't find  this filename %s in the specified directory "
-                                      "(or in the current one, or in the default data directory %s"
+                                      "(or in the current one, or in the default data directory `%s` "
                                       "if directory was not specified " % (filename, prefs.datadir))
             _filenames.append(_f)
 
         # now we have all the filename with their correct location
         filenames = _filenames
-        
+
     if not filename:
         # open a file dialog
         # currently Scpy use QT (needed for next GUI features)
@@ -153,6 +173,9 @@ def readfilename(filename=None, **kwargs):
                 continue
             _, extension = os.path.splitext(filename)
             extension = extension.lower()
+            if extension[1:].isdigit():
+                # probably an opus file
+                extension = 'opus'
             if extension in filenames_dict.keys():
                 filenames_dict[extension].append(filename)
             else:
@@ -172,7 +195,8 @@ def readdirname(dirname=None, **kwargs):
     dirname : `str`, optional.
         A directory name. If not provided, a dialog box is opened to select a directory.
     parent_dir : `str`, optional.
-        The parent directory where to look at. If not specified, read in the current working directory
+        The parent directory where to look at. If not specified, read in the current
+        working directory or the datadir
 
     Returns
     --------
@@ -192,7 +216,7 @@ def readdirname(dirname=None, **kwargs):
         elif os.path.isdir(os.path.join(prefs.datadir, parent_dir)):
             parent_dir = os.path.join(prefs.datadir, parent_dir)
         else:
-            raise ValueError("\"%s\" is not a valid parent directory " % parent_dir)
+            raise ValueError(f'"{parent_dir}" is not a valid parent directory ')
 
     if dirname:
         # if a directory name was provided
@@ -200,7 +224,7 @@ def readdirname(dirname=None, **kwargs):
         if not isinstance(dirname, str):
             # well the directory doesn't exist - we cannot go further without
             # correcting this error
-            raise TypeError("directory %s should be a string!" % dirname)
+            raise TypeError(f'"{dirname}" should be a string!')
 
         # if a valid parent directory has been provided,
         # checks that parent_dir\\dirname is OK
@@ -215,7 +239,9 @@ def readdirname(dirname=None, **kwargs):
             return os.path.join(prefs.datadir, dirname)
 
         else:
-            raise ValueError("\"%s\" is not a valid directory" % dirname)
+            # raise ValueError(f'"{dirname}" is not a valid directory')
+            warnings.warn(f'"{dirname}" is not a valid directory')
+            return None
 
     if not dirname:
         # open a file dialog
@@ -321,8 +347,7 @@ def generate_api(api_path):
             continue
         try:
             pkg = import_item(pkg)
-        except:
-            pkg = import_item(pkg)
+        except Exception:
             raise ImportError(pkg)
         if not hasattr(pkg, '__all__'):
             continue
@@ -388,7 +413,8 @@ def unzip(source_filename, dest_dir):
             for word in words[:-1]:
                 drive, word = os.path.splitdrive(word)
                 head, word = os.path.split(word)
-                if word in (os.curdir, os.pardir, ''): continue
+                if word in (os.curdir, os.pardir, ''):
+                    continue
                 path = os.path.join(path, word)
             zf.extract(member, path)
 
