@@ -16,9 +16,8 @@ __all__ = [
     "TYPE_INTEGER",
     "TYPE_COMPLEX",
     "TYPE_FLOAT",
-    "HAS_PANDAS",
-    "HAS_XARRAY",
-
+    "EPSILON",
+    "INPLACE",
     "make_new_object",
     "getdocfrom",
     "dict_compare",
@@ -34,7 +33,6 @@ __all__ = [
     'srepr',
     "spacing",
 
-    
     #
 ]
 
@@ -44,12 +42,9 @@ import os
 import numpy as np
 import sys
 from contextlib import contextmanager
-import inspect
 import functools
 from datetime import datetime
 import uuid
-import warnings
-
 
 #
 # constants
@@ -58,19 +53,11 @@ TYPE_INTEGER = (int, np.int_, np.int32, np.int64)
 TYPE_FLOAT = (float, np.float_, np.float32, np.float64)
 TYPE_COMPLEX = (complex, np.complex_, np.complex64, np.complex128)
 
-try:
-    import pandas as pd
+EPSILON = epsilon = np.finfo(float).eps
+"Minimum value before considering it as zero value"
 
-    HAS_PANDAS = True
-except ImportError:
-    HAS_PANDAS = False
-
-try:
-    import xarray as xr
-
-    HAS_XARRAY = True
-except ImportError:
-    HAS_XARRAY = False
+INPLACE = "INPLACE"
+"Flag used to specify inplace slicing"
 
 def make_new_object(obj):
     """
@@ -133,7 +120,7 @@ except ImportError:
 
 class _DummyFile(object):
     """
-    A noop writeable object.
+    A writeable object.
 
     """
 
@@ -241,7 +228,7 @@ def makedirs(newdir):
     if os.path.isdir(newdir):
         pass
     elif os.path.isfile(newdir):
-        raise OSError("a file with the same name as the desired " \
+        raise OSError("a file with the same name as the desired "
                       "dir, '%s', already exists." % newdir)
     else:
         head, tail = os.path.split(newdir)
@@ -367,18 +354,18 @@ def srepr(arg):
     return repr(arg)
 
 
-def makestr(l):
+def makestr(li):
     """
     make a string from a list of string
 
     """
 
-    if is_sequence(l):
-        l = " ".join(map(str, l))
-    l = l.replace('$', '')
-    l = l.replace(' ', '\ ')
-    l = r'$%s$' % l
-    return l
+    if is_sequence(li):
+        li = " ".join(map(str, li))
+    li = li.replace('$', '')
+    li = li.replace(' ', r'\ ')
+    li = r'$%s$' % li
+    return li
 
 
 def primefactors(n):
@@ -398,7 +385,7 @@ def spacing(arr):
     """
     Return a scalar for the spacing in the one-dimensional input array (if it is uniformly spaced,
     else return an array of the different spacings
-    
+
     Parameters
     ----------
     arr : 1D np.array
@@ -406,7 +393,7 @@ def spacing(arr):
     Returns
     -------
     out : float or array
-    
+
     """
     spacings = np.diff(arr)
     # we need to take into account only the significative digits ( but round to some decimals doesn't work
@@ -420,6 +407,3 @@ def spacing(arr):
         return spacings[0]
     else:
         return spacings
-
-
-
