@@ -1,18 +1,13 @@
 #! python3
-
 # -*- coding: utf-8 -*-
 #
 # ======================================================================================================================
 # Copyright (©) 2015-2020 LCS
 # Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT  
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
 # See full LICENSE agreement in the root directory
 # ======================================================================================================================
 
-
-"""
-
-"""
 __all__ = ["assert_equal",
            "assert_array_equal",
            "assert_array_almost_equal",
@@ -28,18 +23,14 @@ __all__ = ["assert_equal",
            ]
 
 import os
-import sys
 import functools
 import tempfile
 import warnings
-
-import nbformat
 import pytest
+import numpy as np
 
 import matplotlib.pyplot as plt
 from matplotlib.testing.compare import calculate_rms, ImageComparisonFailure
-from nbconvert.preprocessors import ExecutePreprocessor
-from nbconvert.preprocessors.execute import CellExecutionError
 from numpy.testing import (assert_equal, assert_array_equal,
                            assert_array_almost_equal, assert_approx_equal, assert_raises)
 
@@ -63,11 +54,11 @@ datadir = datadir()
 figures_dir = os.path.join(os.path.expanduser("~"), ".spectrochempy", "figures")
 os.makedirs(figures_dir, exist_ok=True)
 
-# utilities
-is_sequence = lambda arg: (not hasattr(arg, 'strip')) and hasattr(arg,
-                                                                  "__iter__")
 
-import numpy as np
+# utilities
+def is_sequence(arg):
+    return (not hasattr(arg, 'strip')) and hasattr(arg, "__iter__")
+
 
 EPSILON = epsilon = np.finfo(float).eps
 
@@ -214,62 +205,20 @@ class catch_warnings(warnings.catch_warnings):
 
 
 # ----------------------------------------------------------------------------------------------------------------------
-# Testing examples and notebooks in docs
+# Testing examples and notebooks (Py version) in docs
 # ----------------------------------------------------------------------------------------------------------------------
 
-# .............................................................................
-def notebook_run(path):
-    """
-    Execute a notebook via nbconvert and collect output.
-
-    returns
-    -------
-
-     results : (parsed nb object, execution errors)
-
-    """
-    import sys
-    import subprocess
-
-    print(sys.version_info)
-    kernel_name = 'python%d' % sys.version_info[0]
-    this_file_directory = os.path.dirname(__file__)
-    errors = []
-
-    with open(path) as f:
-        nb = nbformat.read(f, as_version=4)
-        nb.metadata.get('kernelspec', {})['name'] = kernel_name
-        ep = ExecutePreprocessor(kernel_name=kernel_name,
-                                 timeout=10, allow_errors=True)
-
-        try:
-            ep.preprocess(nb, {'metadata': {'path': this_file_directory}})
-
-        except CellExecutionError as e:
-            if "SKIP" in e.traceback:
-                print(str(e.traceback).split("\n")[-2])
-            else:
-                raise e
-
-    return nb, errors
-
-
 # .............................................................................
 def example_run(path):
     import subprocess
 
-    try:
-        print('env', os.environ['CONDA_DEFAULT_ENV'])
-    except:
-        pass
-        #debug_('no conda env')
     pipe = None
     try:
         pipe = subprocess.Popen(
-            ["python", path, ],
+            ["python", path, '--nodisplay'],
             stdout=subprocess.PIPE)
         (so, serr) = pipe.communicate()
-    except:
+    except Exception:
         pass
 
     return pipe.returncode, so, serr
@@ -307,7 +256,7 @@ def _image_compare(imgpath1, imgpath2, REDO_ON_TYPEERROR):
                    multichannel=True) * 100.
         rms = _compute_rms(img1, img2)
 
-    except ValueError as e:
+    except ValueError:
         rms = sim = -1
 
     except TypeError as e:
@@ -331,7 +280,7 @@ def compare_images(imgpath1, imgpath2,
 
     CHECKSIM = (min_similarity is not None)
     SIM = min_similarity if CHECKSIM else 100. - EPSILON
-    MESSSIM = mess = "(similarity : {:.2f}%)".format(sim)
+    MESSSIM = "(similarity : {:.2f}%)".format(sim)
     CHECKRMS = (max_rms is not None and not CHECKSIM)
     RMS = max_rms if CHECKRMS else EPSILON
     MESSRMS = "(rms : {:.2f})".format(rms)
@@ -439,7 +388,7 @@ def image_comparison(reference=None,
 
             # execute the function generating the figures
             # rest style to basic 'lcs' style
-            res = func(*args, **kwargs)
+            _ = func(*args, **kwargs)
 
             # get the new fignums if any
             curfignums = plt.get_fignums()
@@ -449,13 +398,10 @@ def image_comparison(reference=None,
 
             if not curfignums:
                 # no figure where generated
-                raise RuntimeError('No figure was generated '
-                                   'by the "{}" function. Stopped'.format(
-                    func.__name__))
+                raise RuntimeError(f'No figure was generated by the "{func.__name__}" function. Stopped')
 
             if len(reference) != len(curfignums):
-                raise ValueError('number of reference figures provided desn\'t'
-                                 ' match the number of generated figures.')
+                raise ValueError("number of reference figures provided doesn't match the number of generated figures.")
 
             # Comparison
             REDO_ON_TYPEERROR = False
@@ -496,7 +442,7 @@ def image_comparison(reference=None,
 
                     CHECKSIM = (min_similarity is not None)
                     SIM = min_similarity if CHECKSIM else 100. - EPSILON
-                    MESSSIM = mess = "(similarity : {:.2f}%)".format(sim)
+                    MESSSIM = "(similarity : {:.2f}%)".format(sim)
                     CHECKRMS = (max_rms is not None and not CHECKSIM)
                     RMS = max_rms if CHECKRMS else EPSILON
                     MESSRMS = "(rms : {:.2f})".format(rms)
