@@ -1,25 +1,20 @@
 # -*- coding: utf-8 -*-
+
+# ======================================================================================================================
+#  Copyright (©) 2015-2020 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
+# ======================================================================================================================
+
 #
-# ======================================================================================================================
-# Copyright (©) 2015-2020 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT  
-# See full LICENSE agreement in the root directory
-# ======================================================================================================================
-
-
 """ Tests for the interpolate module
 
 """
 import pytest
 
-from spectrochempy.core import info_
-from spectrochempy.core.processors.interpolate import interpolate
 
 # align
-#-------
+# -------
 
 @pytest.mark.skip
 def test_interpolate(ds1, ds2):
     pass
-    
\ No newline at end of file
