@@ -1,30 +1,25 @@
 # -*- coding: utf-8 -*-
+
+# ======================================================================================================================
+#  Copyright (©) 2015-2020 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
+# ======================================================================================================================
+
 #
 # ======================================================================================================================
 
-# Copyright (©) 2015-2020 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT  
-# See full LICENSE agreement in the root directory
-# ======================================================================================================================
-
-
-
-
+import os
 
 from spectrochempy import NDDataset, general_preferences as prefs
-
 from spectrochempy.utils.testing import assert_approx_equal
-import os
-import pytest
 
-#datasets are defined in conftest as fixture
+
+# datasets are defined in conftest as fixture
 
 
 def test_load(IR_dataset_2D):
-
     dataset = IR_dataset_2D
-    assert_approx_equal(dataset.data[0,0], 2.05, significant=2)
+    assert_approx_equal(dataset.data[0, 0], 2.05, significant=2)
     B = dataset * 1.98
     assert_approx_equal(B.data[0, 0], 2.05 * 1.98, significant=2)
     assert "Binary operation mul with `1.98` has been performed" in B.history
@@ -35,14 +30,14 @@ def test_load(IR_dataset_2D):
 
     assert dataset == dataset2
 
-def test_methods_read_access():
 
+def test_methods_read_access():
     path = os.path.join(prefs.datadir, 'nmrdata', 'bruker', 'tests',
-                        'nmr','bruker_1d')
+                        'nmr', 'bruker_1d')
 
     # load the data in a new dataset
     ndd = NDDataset()
     ndd.read_bruker_nmr(path, expno=1, remove_digital_filter=True)
 
     # alternatively
-    ndd = NDDataset.read_bruker_nmr(path, expno=1, remove_digital_filter=True)
+    NDDataset.read_bruker_nmr(path, expno=1, remove_digital_filter=True)
